@@ -18,7 +18,7 @@ exec2man="$1"
 outdir="$2"
 
 mkdir -p "$outdir"
-for program in $(find . -type f -executable -iname 'mlpack_*' | \
+for program in $(find . -type f -perm -u+x -iname 'mlpack_*' | \
                 grep -v '[.]$' | \
                 grep -v '_test$'); do
   echo "Generating man page for $program...";
