@@ -6,8 +6,13 @@
 #define STB_IMAGE_WRITE_STATIC
 #define STB_IMAGE_WRITE_IMPLEMENTATION
 
-#include <stb_image.h>
-#include <stb_image_write.h>
+#ifdef MLPACK_HAS_NO_STB_DIR
+  #include <stb_image.h>
+  #include <stb_image_write.h>
+#else
+  #include <stb/stb_image.h>
+  #include <stb/stb_image_write.h>
+#endif
 
 void A::A()
 {
