@@ -315,3 +315,47 @@ test_that("TestSerialization", {
 
   expect_true(output2$model_bw_out == 20)
 })
+
+# Make sure that the verbose argument does anything at all.
+test_that("TestVerbose", {
+  expect_output(test_r_binding(4.0, 12, "hello",
+                               build_model=TRUE,
+                               verbose=TRUE))
+})
+
+# Test that we get no output when verbose output is disabled.
+test_that("TestNotVerbose", {
+  # Make sure that global verbosity is turned off.
+  options(mlpack.verbose = FALSE)
+  expect_silent(test_r_binding(4.0, 12, "hello",
+                               build_model=TRUE))
+})
+
+# Test that we get no output when verbose output is explicitly disabled.
+test_that("TestReallyNotVerbose", {
+  expect_silent(test_r_binding(4.0, 12, "hello",
+                               build_model=TRUE,
+                               verbose=FALSE))
+})
+
+# Make sure that the mlpack verbose global option does anything at all.
+test_that("TestGlobalVerbose", {
+  options(mlpack.verbose = TRUE)
+  expect_output(test_r_binding(4.0, 12, "hello",
+                               build_model=TRUE))
+})
+
+# Test that we get no output when the global verbose option is set to false.
+test_that("TestGlobalNotVerbose", {
+  options(mlpack.verbose = FALSE)
+  expect_silent(test_r_binding(4.0, 12, "hello",
+                               build_model=TRUE))
+})
+
+# Test that we can override the global verbose option.
+test_that("TestGlobalVerboseOverride", {
+  options(mlpack.verbose = TRUE)
+  expect_silent(test_r_binding(4.0, 12, "hello",
+                               build_model=TRUE,
+                               verbose=FALSE))
+})
