@@ -25,19 +25,19 @@ namespace cli {
 template<typename T>
 std::string GetPrintableType(
     util::ParamData& data,
-    const typename std::enable_if<!arma::is_arma_type<T>::value>::type*,
-    const typename std::enable_if<!util::IsStdVector<T>::value>::type*,
-    const typename std::enable_if<!data::HasSerialize<T>::value>::type*,
-    const typename std::enable_if<!std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>::value>::type*)
+    const std::enable_if_t<!arma::is_arma_type<T>::value>*,
+    const std::enable_if_t<!util::IsStdVector<T>::value>*,
+    const std::enable_if_t<!data::HasSerialize<T>::value>*,
+    const std::enable_if_t<!std::is_same_v<T,
+        std::tuple<data::DatasetInfo, arma::mat>>>*)
 {
-  if (std::is_same<T, bool>::value)
+  if (std::is_same_v<T, bool>)
     return "flag";
-  else if (std::is_same<T, int>::value)
+  else if (std::is_same_v<T, int>)
     return "int";
-  else if (std::is_same<T, double>::value)
+  else if (std::is_same_v<T, double>)
     return "double";
-  else if (std::is_same<T, std::string>::value)
+  else if (std::is_same_v<T, std::string>)
     return "string";
   else
     throw std::invalid_argument("unknown parameter type" + data.cppType);
@@ -49,11 +49,11 @@ std::string GetPrintableType(
 template<typename T>
 std::string GetPrintableType(
     util::ParamData& data,
-    const typename std::enable_if<util::IsStdVector<T>::value>::type*)
+    const std::enable_if_t<util::IsStdVector<T>::value>*)
 {
-  if (std::is_same<T, std::vector<int>>::value)
+  if (std::is_same_v<T, std::vector<int>>)
     return "int vector";
-  else if (std::is_same<T, std::vector<std::string>>::value)
+  else if (std::is_same_v<T, std::vector<std::string>>)
     return "string vector";
   else
     throw std::invalid_argument("unknown vector type " + data.cppType);
@@ -65,19 +65,19 @@ std::string GetPrintableType(
 template<typename T>
 std::string GetPrintableType(
     util::ParamData& data,
-    const typename std::enable_if<arma::is_arma_type<T>::value>::type*)
+    const std::enable_if_t<arma::is_arma_type<T>::value>*)
 {
-  if (std::is_same<T, arma::mat>::value)
+  if (std::is_same_v<T, arma::mat>)
     return "2-d matrix file";
-  else if (std::is_same<T, arma::Mat<size_t>>::value)
+  else if (std::is_same_v<T, arma::Mat<size_t>>)
     return "2-d index matrix file";
-  else if (std::is_same<T, arma::rowvec>::value)
+  else if (std::is_same_v<T, arma::rowvec>)
     return "1-d matrix file";
-  else if (std::is_same<T, arma::Row<size_t>>::value)
+  else if (std::is_same_v<T, arma::Row<size_t>>)
     return "1-d index matrix file";
-  else if (std::is_same<T, arma::vec>::value)
+  else if (std::is_same_v<T, arma::vec>)
     return "1-d matrix file";
-  else if (std::is_same<T, arma::Col<size_t>>::value)
+  else if (std::is_same_v<T, arma::Col<size_t>>)
     return "1-d index matrix file";
   else
     throw std::invalid_argument("unknown Armadillo type" + data.cppType);
@@ -89,8 +89,8 @@ std::string GetPrintableType(
 template<typename T>
 std::string GetPrintableType(
     util::ParamData& /* data */,
-    const typename std::enable_if<std::is_same<T,
-        std::tuple<data::DatasetInfo, arma::mat>>::value>::type*)
+    const std::enable_if_t<std::is_same_v<T,
+        std::tuple<data::DatasetInfo, arma::mat>>>*)
 {
   return "2-d categorical matrix file";
 }
@@ -101,8 +101,8 @@ std::string GetPrintableType(
 template<typename T>
 std::string GetPrintableType(
     util::ParamData& data,
-    const typename std::enable_if<!arma::is_arma_type<T>::value>::type*,
-    const typename std::enable_if<data::HasSerialize<T>::value>::type*)
+    const std::enable_if_t<!arma::is_arma_type<T>::value>*,
+    const std::enable_if_t<data::HasSerialize<T>::value>*)
 {
   return data.cppType + " file";
 }
