@@ -25,9 +25,8 @@ void SetMemState(T& t, int state)
   // If we just "released" the memory, so that the matrix does not own it, with
   // Armadillo 10 we must also ensure that the matrix does not deallocate the
   // memory by specifying `n_alloc = 0`.
-  #if ARMA_VERSION_MAJOR >= 10
-    const_cast<arma::uword&>(t.n_alloc) = 0;
-  #endif
+
+  const_cast<arma::uword&>(t.n_alloc) = 0;
 }
 
 /**
