@@ -14,8 +14,9 @@
 #define MLPACK_CORE_UTIL_HAS_SERIALIZE_HPP
 
 #include <mlpack/core/util/sfinae_utility.hpp>
-#include <boost/serialization/serialization.hpp>
-#include <boost/archive/xml_oarchive.hpp>
+#include <cereal/archives/xml.hpp>
+#include <cereal/cereal.hpp>
+
 #include <type_traits>
 
 namespace mlpack {
@@ -31,11 +32,12 @@ template<typename T>
 struct HasSerializeFunction
 {
   template<typename C>
-  using NonStaticSerialize = void(C::*)(boost::archive::xml_oarchive&,
-                                        const unsigned int);
+  using NonStaticSerialize = void(C::*)(cereal::XMLOutputArchive&,
+      const uint32_t version);
+
   template<typename /* C */>
-  using StaticSerialize = void(*)(boost::archive::xml_oarchive&,
-                                  const unsigned int);
+  using StaticSerialize = void(*)(cereal::XMLOutputArchive&,
+      const uint32_t version);
 
   static const bool value = HasSerializeCheck<T, NonStaticSerialize>::value ||
                             HasSerializeCheck<T, StaticSerialize>::value;
@@ -50,7 +52,7 @@ struct HasSerialize
   template<typename U, typename V, typename W> struct check;
   template<typename U> static yes& chk( // This matches classes.
       check<U,
-            typename std::enable_if_t<std::is_class<U>::value>*,
+            typename std::enable_if_t<std::is_class_v<U>>*,
             typename std::enable_if_t<HasSerializeFunction<U>::value>*>*);
   template<typename  > static no&  chk(...); // This matches non-classes.
 
