@@ -160,8 +160,8 @@ void LoadARFF(const std::string& filename,
   }
 
   // Make sure all strings are mapped, if we have any.
-  typedef std::map<size_t, std::vector<std::string>>::const_iterator
-      IteratorType;
+  using IteratorType =
+      std::map<size_t, std::vector<std::string>>::const_iterator;
   for (IteratorType it = categoryStrings.begin(); it != categoryStrings.end();
       ++it)
   {
@@ -211,7 +211,8 @@ void LoadARFF(const std::string& filename,
 
     size_t col = 0;
     std::stringstream token;
-    for (std::vector<std::string>::iterator it = tok.begin(); it != tok.end(); ++it)
+    for (std::vector<std::string>::iterator it = tok.begin(); it != tok.end();
+         ++it)
     {
       // Check that we are not too many columns in.
       if (col >= matrix.n_rows)
