@@ -16,6 +16,7 @@
 #include <unordered_map>
 #include <mlpack/core/data/map_policies/datatype.hpp>
 #include <limits>
+#include <set>
 
 namespace mlpack {
 namespace data {
@@ -111,7 +112,7 @@ class MissingPolicy
           maps[dimension].first.count(string) == 0)
       {
         // This string does not exist yet.
-        typedef std::pair<std::string, MappedType> PairType;
+        using PairType = std::pair<std::string, MappedType>;
         maps[dimension].first.insert(PairType(string, value));
 
         // Insert right mapping too.
