@@ -1,5 +1,5 @@
 /**
- * @file cv_function.hpp
+ * @file core/hpt/cv_function.hpp
  * @author Kirill Mishchenko
  *
  * A cross-validation wrapper for optimizers.
@@ -15,7 +15,6 @@
 #include <mlpack/core.hpp>
 
 namespace mlpack {
-namespace hpt {
 
 /**
  * This wrapper serves for adapting the interface of the cross-validation
@@ -55,7 +54,7 @@ class CVFunction
    *     derivatives (by the definition). This value is going to be used when it
    *     is greater than the increase calculated with the rules described in the
    *     documentation for the relativeDelta parameter.
-   * @param BoundArgs Arguments that should be passed into the Evaluate method
+   * @param args Arguments that should be passed into the Evaluate method
    *     of the CVType object but are not going to be passed into the Evaluate
    *     method of this object.
    */
@@ -131,8 +130,8 @@ class CVFunction
   template<size_t BoundArgIndex,
            size_t ParamIndex,
            typename... Args,
-           typename = typename
-               std::enable_if<(BoundArgIndex + ParamIndex < TotalArgs)>::type>
+           typename =
+               std::enable_if_t<(BoundArgIndex + ParamIndex < TotalArgs)>>
   inline double Evaluate(const arma::mat& parameters, const Args&... args);
 
   /**
@@ -141,8 +140,8 @@ class CVFunction
   template<size_t BoundArgIndex,
            size_t ParamIndex,
            typename... Args,
-           typename = typename
-               std::enable_if<BoundArgIndex + ParamIndex == TotalArgs>::type,
+           typename =
+               std::enable_if_t<BoundArgIndex + ParamIndex == TotalArgs>,
            typename = void>
   inline double Evaluate(const arma::mat& parameters, const Args&... args);
 
@@ -152,8 +151,8 @@ class CVFunction
   template<size_t BoundArgIndex,
            size_t ParamIndex,
            typename... Args,
-           typename = typename std::enable_if<
-               UseBoundArg<BoundArgIndex, ParamIndex>::value>::type>
+           typename = std::enable_if_t<
+               UseBoundArg<BoundArgIndex, ParamIndex>::value>>
   inline double PutNextArg(const arma::mat& parameters, const Args&... args);
 
   /**
@@ -163,14 +162,13 @@ class CVFunction
   template<size_t BoundArgIndex,
            size_t ParamIndex,
            typename... Args,
-           typename = typename std::enable_if<
-               !UseBoundArg<BoundArgIndex, ParamIndex>::value>::type,
+           typename = std::enable_if_t<
+               !UseBoundArg<BoundArgIndex, ParamIndex>::value>,
            typename = void>
   inline double PutNextArg(const arma::mat& parameters, const Args&... args);
 };
 
 
-} // namespace hpt
 } // namespace mlpack
 
 // Include implementation
