@@ -17,25 +17,6 @@
 
 namespace mlpack {
 
-/**
- * @brief Kernel functions.
- *
- * This namespace contains kernel functions, which evaluate some kernel function
- * @f$ K(x, y) @f$ for some arbitrary vectors @f$ x @f$ and @f$ y @f$ of the
- * same dimension.  The single restriction on the function @f$ K(x, y) @f$ is
- * that it must satisfy Mercer's condition:
- *
- * @f[
- * \int \int K(x, y) g(x) g(y) dx dy \ge 0
- * @f]
- *
- * for all square integrable functions @f$ g(x) @f$.
- *
- * The kernels in this namespace all implement the KernelType policy.  For more
- * information, see \ref kernels "The KernelType policy documentation".
- */
-namespace kernel {
-
 /**
  * An example kernel function.  This is not a useful kernel, but it implements
  * the two functions necessary to satisfy the Kernel policy (so that a class can
@@ -106,25 +87,7 @@ class ExampleKernel
    * not need to do anything at all.
    */
   template<typename Archive>
-  void serialize(Archive& /* ar */, const unsigned int /* version */) { }
-
-  /**
-   * Obtains the convolution integral [integral K(||x-a||)K(||b-x||)dx]
-   * for the two vectors.  In this case, because
-   * our simple example kernel has no internal parameters, we can declare the
-   * function static.  For a more complex example which cannot be declared
-   * static, see the GaussianKernel, which stores an internal parameter.
-   *
-   * @tparam VecTypeA Type of first vector (arma::vec, arma::sp_vec should be
-   *      expected).
-   * @tparam VecTypeB Type of second vector (arma::vec, arma::sp_vec).
-   * @param * (a) First vector.
-   * @param * (b) Second vector.
-   * @return the convolution integral value.
-   */
-  template<typename VecTypeA, typename VecTypeB>
-  static double ConvolutionIntegral(const VecTypeA& /* a */,
-                                    const VecTypeB& /* b */) { return 0; }
+  void serialize(Archive& /* ar */, const uint32_t /* version */) { }
 
   /**
    * Obtains the normalizing volume for the kernel with dimension $dimension$.
@@ -141,7 +104,6 @@ class ExampleKernel
   // static double Normalizer(size_t dimension=1) { return 0; }
 };
 
-} // namespace kernel
 } // namespace mlpack
 
 #endif
