@@ -49,62 +49,55 @@ struct IsCube
   static const bool value = false;
 };
 
-// Commenting out the first template per case, because
-// Visual Studio doesn't like this instantiation pattern (error C2910).
-// template<>
+template<typename FieldType>
+struct IsField
+{
+  static const bool value = false;
+};
+
+template<typename T>
+struct IsAnyArmaBaseType
+{
+  static const bool value = IsVector<T>::value || IsMatrix<T>::value ||
+      IsCube<T>::value || IsField<T>::value;
+};
+
 template<typename eT>
 struct IsVector<arma::Col<eT> >
 {
   static const bool value = true;
 };
 
-// template<>
 template<typename eT>
 struct IsVector<arma::SpCol<eT> >
 {
   static const bool value = true;
 };
 
-// template<>
 template<typename eT>
 struct IsVector<arma::Row<eT> >
 {
   static const bool value = true;
 };
 
-// template<>
 template<typename eT>
 struct IsVector<arma::SpRow<eT> >
 {
   static const bool value = true;
 };
 
-// template<>
 template<typename eT>
 struct IsVector<arma::subview_col<eT> >
 {
   static const bool value = true;
 };
 
-// template<>
 template<typename eT>
 struct IsVector<arma::subview_row<eT> >
 {
   static const bool value = true;
 };
 
-template<typename eT>
-struct IsMatrix<arma::Mat<eT> >
-{
-  static const bool value = true;
-};
-
-template<typename eT>
-struct IsCube<arma::Cube<eT> >
-{
-  static const bool value = true;
-};
-
 template<typename eT>
 struct IsVector<arma::SpSubview_col<eT> >
 {
@@ -117,6 +110,30 @@ struct IsVector<arma::SpSubview_row<eT> >
   static const bool value = true;
 };
 
+template<typename eT>
+struct IsMatrix<arma::Mat<eT> >
+{
+  static const bool value = true;
+};
+
+template<typename eT>
+struct IsMatrix<arma::SpMat<eT> >
+{
+  static const bool value = true;
+};
+
+template<typename eT>
+struct IsCube<arma::Cube<eT> >
+{
+  static const bool value = true;
+};
+
+template<typename eT>
+struct IsField<arma::field<eT> >
+{
+  static const bool value = true;
+};
+
 // Get the row vector type corresponding to a given MatType.
 
 template<typename MatType>
@@ -281,4 +298,28 @@ struct IsBaseMatType<arma::SpRow<eT>>
   constexpr static bool value = true;
 };
 
+template<typename T>
+struct IsArma
+{
+  constexpr static bool value = arma::is_arma_type<T>::value;
+};
+
+#if defined(MLPACK_HAS_COOT)
+
+template<typename T>
+struct IsCoot
+{
+  constexpr static bool value = coot::is_coot_type<T>::value;
+};
+
+#else
+
+template<typename T>
+struct IsCoot
+{
+  constexpr static bool value = false;
+};
+
+#endif
+
 #endif
