@@ -77,8 +77,7 @@ class MultiheadAttentionType : public Layer<MatType>
   /**
    * Create the MultiheadAttention object using the specified modules.
    * The attnMask and keyPaddingMask arguments are defined as a mask
-   * where 1 passes values and 0 masks them, unlike the original
-   * paper which uses 0 to pass values and -inf to mask them.
+   * 0 passes values and -inf masks them, as in the original paper.
    *
    * @param tgtSeqLen Target sequence length.
    * @param numHeads Number of parallel attention heads.
@@ -103,7 +102,7 @@ class MultiheadAttentionType : public Layer<MatType>
   /**
    * Reset the layer parameters.
    */
-  void SetWeights(typename MatType::elem_type* weightsPtr) override;
+  void SetWeights(const MatType& weightsIn) override;
 
   /**
    * Ordinary feed forward pass of a neural network, evaluating the function
@@ -184,8 +183,8 @@ class MultiheadAttentionType : public Layer<MatType>
   //! Modify the Key Padding Mask.  Should take values 0 or 1.
   MatType& KeyPaddingMask() { return keyPaddingMask; }
 
-  //! Get whether or not self-attention is used (source key, value, and query all
-  //! come from the same input).
+  //! Get whether or not self-attention is used (source key, value, and query
+  //! all come from the same input).
   bool SelfAttention() const { return selfAttention; }
   //! Modify whether or not self-attention is used (source key, value, and query
   //! all come from the same input).
@@ -266,7 +265,7 @@ class MultiheadAttentionType : public Layer<MatType>
 
  private:
   //! Element Type of the output.
-  typedef typename MatType::elem_type ElemType;
+  using ElemType = typename MatType::elem_type;
 
   //! Target sequence length.
   size_t tgtSeqLen;
@@ -344,7 +343,7 @@ class MultiheadAttentionType : public Layer<MatType>
 }; // class MultiheadAttention
 
 // Standard MultiheadAttention layer using no regularization.
-typedef MultiheadAttentionType<arma::mat, NoRegularizer> MultiheadAttention;
+using MultiheadAttention = MultiheadAttentionType<arma::mat, NoRegularizer>;
 
 } // namespace mlpack
 
