@@ -52,7 +52,7 @@ class NoisyLinearType : public Layer<MatType>
   NoisyLinearType& operator=(NoisyLinearType&& other);
 
   //! Reset the layer parameter.
-  void SetWeights(typename MatType::elem_type* weightsPtr);
+  void SetWeights(const MatType& weightsIn);
 
   //! Reset the noise parameters (epsilons).
   void ResetNoise();
@@ -147,13 +147,12 @@ class NoisyLinearType : public Layer<MatType>
 
   //! Locally-stored bias-epsilon parameters.
   MatType biasEpsilon;
-
 }; // class NoisyLinearType
 
 // Convenience typedefs.
 
 // Standard noisy linear layer.
-typedef NoisyLinearType<arma::mat> NoisyLinear;
+using NoisyLinear = NoisyLinearType<arma::mat>;
 
 } // namespace mlpack
 
