@@ -29,17 +29,17 @@ HMM<Distribution>::HMM(const size_t states,
                        const Distribution emissions,
                        const double tolerance) :
     emission(states, /* default distribution */ emissions),
-    transitionProxy(arma::randu<arma::mat>(states, states)),
-    initialProxy(arma::randu<arma::vec>(states) / (double) states),
+    transitionProxy(randu<arma::mat>(states, states)),
+    initialProxy(randu<arma::vec>(states) / (double) states),
     dimensionality(emissions.Dimensionality()),
     tolerance(tolerance),
     recalculateInitial(false),
     recalculateTransition(false)
 {
   // Normalize the transition probabilities and initial state probabilities.
-  initialProxy /= arma::accu(initialProxy);
+  initialProxy /= accu(initialProxy);
   for (size_t i = 0; i < transitionProxy.n_cols; ++i)
-    transitionProxy.col(i) /= arma::accu(transitionProxy.col(i));
+    transitionProxy.col(i) /= accu(transitionProxy.col(i));
 
   logTransition = log(transitionProxy);
   logInitial = log(initialProxy);
@@ -193,7 +193,7 @@ double HMM<Distribution>::Train(const std::vector<arma::mat>& dataSeq)
 
         // Add to list of emission observations, for Distribution::Train().
         for (size_t j = 0; j < logTransition.n_cols; ++j)
-          emissionProb[j][sumTime] = exp(stateLogProb(j, t));
+          emissionProb[j][sumTime] = std::exp(stateLogProb(j, t));
         emissionList.col(sumTime) = dataSeq[seq].col(t);
         sumTime++;
       }
@@ -226,7 +226,7 @@ double HMM<Distribution>::Train(const std::vector<arma::mat>& dataSeq)
       if (std::isfinite(sum))
         logTransition.col(i) -= sum;
       else
-        logTransition.col(i).fill(-log((double) logTransition.n_rows));
+        logTransition.col(i).fill(-std::log((double) logTransition.n_rows));
     }
 
     initialProxy = exp(logInitial);
@@ -257,9 +257,8 @@ void HMM<Distribution>::Train(const std::vector<arma::mat>& dataSeq,
         << ")." << std::endl;
   }
 
-  arma::mat initial = arma::zeros(logInitial.n_elem);
-  arma::mat transition = arma::zeros(logTransition.n_rows,
-                                     logTransition.n_cols);
+  arma::mat initial = zeros(logInitial.n_elem);
+  arma::mat transition = zeros(logTransition.n_rows, logTransition.n_cols);
 
   // Estimate the transition and emission matrices directly from the
   // observations.  The emission list holds the time indices for observations
@@ -463,7 +462,7 @@ void HMM<Distribution>::Generate(const size_t length,
     double probSum = 0;
     for (size_t st = 0; st < logTransition.n_rows; st++)
     {
-      probSum += exp(logTransition(st, stateSequence[t - 1]));
+      probSum += std::exp(logTransition(st, stateSequence[t - 1]));
       if (randValue <= probSum)
       {
         stateSequence[t] = st;
@@ -529,13 +528,14 @@ double HMM<Distribution>::Predict(const arma::mat& dataSeq,
     for (size_t j = 0; j < logTransition.n_rows; j++)
     {
       arma::vec prob = logStateProb.col(t - 1) + logTransition.row(j).t();
-      logStateProb(j, t) = prob.max(index) + logProbs(t, j);
+      index = prob.index_max();
+      logStateProb(j, t) = prob[index] + logProbs(t, j);
       stateSeqBack(j, t) = index;
     }
   }
 
   // Backtrack to find the most probable state sequence.
-  logStateProb.unsafe_col(dataSeq.n_cols - 1).max(index);
+  index = logStateProb.unsafe_col(dataSeq.n_cols - 1).index_max();
   stateSeq[dataSeq.n_cols - 1] = index;
   for (size_t t = 2; t <= dataSeq.n_cols; t++)
   {
