@@ -14,40 +14,64 @@
 
 // In case it hasn't been included yet.
 #include "hoeffding_tree.hpp"
-#include <stack>
 
 namespace mlpack {
-namespace tree {
 
 template<typename FitnessFunction,
          template<typename> class NumericSplitType,
          template<typename> class CategoricalSplitType>
-template<typename MatType>
 HoeffdingTree<
     FitnessFunction,
     NumericSplitType,
     CategoricalSplitType
->::HoeffdingTree(const MatType& data,
-                 const data::DatasetInfo& datasetInfo,
-                 const arma::Row<size_t>& labels,
+>::HoeffdingTree() :
+    dimensionMappings(
+        new std::unordered_map<size_t, std::pair<size_t, size_t>>()),
+    ownsMappings(true),
+    numSamples(0),
+    numClasses(0),
+    maxSamples(size_t(-1)),
+    checkInterval(100),
+    minSamples(100),
+    datasetInfo(new data::DatasetInfo()),
+    ownsInfo(true),
+    successProbability(0.95),
+    splitDimension(size_t(-1)),
+    majorityClass(0),
+    majorityProbability(0.0),
+    categoricalSplit(0),
+    numericSplit()
+{
+  // Nothing to do.
+}
+
+template<typename FitnessFunction,
+         template<typename> class NumericSplitType,
+         template<typename> class CategoricalSplitType>
+HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::HoeffdingTree(const size_t dimensionality,
                  const size_t numClasses,
-                 const bool batchTraining,
                  const double successProbability,
                  const size_t maxSamples,
                  const size_t checkInterval,
                  const size_t minSamples,
                  const CategoricalSplitType<FitnessFunction>&
                      categoricalSplitIn,
-                 const NumericSplitType<FitnessFunction>& numericSplitIn) :
-    dimensionMappings(new std::unordered_map<size_t,
-        std::pair<size_t, size_t>>()),
-    ownsMappings(true),
+                 const NumericSplitType<FitnessFunction>& numericSplitIn,
+                 std::unordered_map<size_t, std::pair<size_t, size_t>>*
+                     dimensionMappingsIn) :
+    dimensionMappings((dimensionMappingsIn != NULL) ? dimensionMappingsIn :
+        new std::unordered_map<size_t, std::pair<size_t, size_t>>()),
+    ownsMappings(dimensionMappingsIn == NULL),
     numSamples(0),
     numClasses(numClasses),
     maxSamples((maxSamples == 0) ? size_t(-1) : maxSamples),
     checkInterval(checkInterval),
     minSamples(minSamples),
-    datasetInfo(new data::DatasetInfo(datasetInfo)),
+    datasetInfo(new data::DatasetInfo(dimensionality)),
     ownsInfo(true),
     successProbability(successProbability),
     splitDimension(size_t(-1)),
@@ -56,27 +80,20 @@ HoeffdingTree<
     categoricalSplit(0),
     numericSplit()
 {
-  // Generate dimension mappings and create split objects.
-  for (size_t i = 0; i < datasetInfo.Dimensionality(); ++i)
+  // Do we need to generate the mappings too?
+  if (ownsMappings)
   {
-    if (datasetInfo.Type(i) == data::Datatype::categorical)
-    {
-      categoricalSplits.push_back(CategoricalSplitType<FitnessFunction>(
-          datasetInfo.NumMappings(i), numClasses, categoricalSplitIn));
-      (*dimensionMappings)[i] = std::make_pair(data::Datatype::categorical,
-          categoricalSplits.size() - 1);
-    }
-    else
+    ResetTree(categoricalSplitIn, numericSplitIn);
+  }
+  else
+  {
+    // All dimensions are numeric.
+    for (size_t i = 0; i < datasetInfo->Dimensionality(); ++i)
     {
       numericSplits.push_back(NumericSplitType<FitnessFunction>(numClasses,
           numericSplitIn));
-      (*dimensionMappings)[i] = std::make_pair(data::Datatype::numeric,
-          numericSplits.size() - 1);
     }
   }
-
-  // Now train.
-  Train(data, labels, batchTraining);
 }
 
 template<typename FitnessFunction,
@@ -119,23 +136,7 @@ HoeffdingTree<
   // Do we need to generate the mappings too?
   if (ownsMappings)
   {
-    for (size_t i = 0; i < datasetInfo.Dimensionality(); ++i)
-    {
-      if (datasetInfo.Type(i) == data::Datatype::categorical)
-      {
-        categoricalSplits.push_back(CategoricalSplitType<FitnessFunction>(
-            datasetInfo.NumMappings(i), numClasses, categoricalSplitIn));
-        (*dimensionMappings)[i] = std::make_pair(data::Datatype::categorical,
-            categoricalSplits.size() - 1);
-      }
-      else
-      {
-        numericSplits.push_back(NumericSplitType<FitnessFunction>(numClasses,
-            numericSplitIn));
-        (*dimensionMappings)[i] = std::make_pair(data::Datatype::numeric,
-            numericSplits.size() - 1);
-      }
-    }
+    ResetTree(categoricalSplitIn, numericSplitIn);
   }
   else
   {
@@ -158,29 +159,86 @@ HoeffdingTree<
 template<typename FitnessFunction,
          template<typename> class NumericSplitType,
          template<typename> class CategoricalSplitType>
+template<typename MatType>
 HoeffdingTree<
     FitnessFunction,
     NumericSplitType,
     CategoricalSplitType
->::HoeffdingTree() :
-    dimensionMappings(
-        new std::unordered_map<size_t, std::pair<size_t, size_t>>()),
-    ownsMappings(true),
+>::HoeffdingTree(const MatType& data,
+                 const arma::Row<size_t>& labels,
+                 const size_t numClasses,
+                 const bool batchTraining,
+                 const double successProbability,
+                 const size_t maxSamples,
+                 const size_t checkInterval,
+                 const size_t minSamples,
+                 const CategoricalSplitType<FitnessFunction>&
+                     categoricalSplitIn,
+                 const NumericSplitType<FitnessFunction>& numericSplitIn) :
+    dimensionMappings(NULL),
+    ownsMappings(false),
     numSamples(0),
-    numClasses(0),
-    maxSamples(size_t(-1)),
-    checkInterval(100),
-    minSamples(100),
-    datasetInfo(new data::DatasetInfo()),
+    numClasses(numClasses),
+    maxSamples((maxSamples == 0) ? size_t(-1) : maxSamples),
+    checkInterval(checkInterval),
+    minSamples(minSamples),
+    datasetInfo(new data::DatasetInfo(data.n_rows)),
     ownsInfo(true),
-    successProbability(0.95),
+    successProbability(successProbability),
     splitDimension(size_t(-1)),
     majorityClass(0),
     majorityProbability(0.0),
     categoricalSplit(0),
     numericSplit()
 {
-  // Nothing to do.
+  // Reset the tree.
+  ResetTree(categoricalSplitIn, numericSplitIn);
+
+  // Now train.
+  Train(data, labels, numClasses, batchTraining);
+}
+
+template<typename FitnessFunction,
+         template<typename> class NumericSplitType,
+         template<typename> class CategoricalSplitType>
+template<typename MatType>
+HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::HoeffdingTree(const MatType& data,
+                 const data::DatasetInfo& datasetInfoIn,
+                 const arma::Row<size_t>& labels,
+                 const size_t numClasses,
+                 const bool batchTraining,
+                 const double successProbability,
+                 const size_t maxSamples,
+                 const size_t checkInterval,
+                 const size_t minSamples,
+                 const CategoricalSplitType<FitnessFunction>&
+                     categoricalSplitIn,
+                 const NumericSplitType<FitnessFunction>& numericSplitIn) :
+    dimensionMappings(NULL),
+    ownsMappings(false),
+    numSamples(0),
+    numClasses(numClasses),
+    maxSamples((maxSamples == 0) ? size_t(-1) : maxSamples),
+    checkInterval(checkInterval),
+    minSamples(minSamples),
+    datasetInfo(new data::DatasetInfo(datasetInfoIn)),
+    ownsInfo(true),
+    successProbability(successProbability),
+    splitDimension(size_t(-1)),
+    majorityClass(0),
+    majorityProbability(0.0),
+    categoricalSplit(0),
+    numericSplit()
+{
+  // Reset the tree.
+  ResetTree(categoricalSplitIn, numericSplitIn);
+
+  // Now train.
+  Train(data, labels, numClasses, batchTraining);
 }
 
 // Copy constructor.
@@ -224,6 +282,138 @@ HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>::
   }
 }
 
+// Move constructor.
+template<typename FitnessFunction,
+         template<typename> class NumericSplitType,
+         template<typename> class CategoricalSplitType>
+HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>::
+    HoeffdingTree(HoeffdingTree&& other) :
+    numericSplits(std::move(other.numericSplits)),
+    categoricalSplits(std::move(other.categoricalSplits)),
+    dimensionMappings(other.dimensionMappings),
+    ownsMappings(true),
+    numSamples(other.numSamples),
+    numClasses(other.numClasses),
+    maxSamples(other.maxSamples),
+    checkInterval(other.checkInterval),
+    minSamples(other.minSamples),
+    datasetInfo(other.datasetInfo),
+    ownsInfo(true),
+    successProbability(other.successProbability),
+    splitDimension(other.splitDimension),
+    majorityClass(other.majorityClass),
+    majorityProbability(other.majorityProbability),
+    categoricalSplit(std::move(other.categoricalSplit)),
+    numericSplit(std::move(other.numericSplit))
+{
+  // Remove pointers.
+  other.dimensionMappings = nullptr;
+  other.datasetInfo = nullptr;
+
+  // Reset primary type variables.
+  other.numSamples = 0;
+  other.numClasses = 0;
+  other.checkInterval = 0;
+  other.minSamples = 0;
+  other.successProbability = 0.0;
+  other.splitDimension = 0;
+  other.majorityClass = 0;
+  other.majorityProbability = 0.0;
+}
+
+// Copy assignment operator.
+template<typename FitnessFunction,
+         template<typename> class NumericSplitType,
+         template<typename> class CategoricalSplitType>
+HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>&
+    HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>::
+    operator=(const HoeffdingTree& other)
+{
+  if (this != &other)
+  {
+    numericSplits = other.numericSplits;
+    categoricalSplits = other.categoricalSplits;
+    dimensionMappings = new std::unordered_map<size_t,
+        std::pair<size_t, size_t>>(*other.dimensionMappings);
+    ownsMappings = true;
+    numSamples = other.numSamples;
+    numClasses = other.numClasses;
+    maxSamples = other.maxSamples;
+    checkInterval = other.checkInterval;
+    minSamples = other.minSamples;
+    datasetInfo = new data::DatasetInfo(*other.datasetInfo);
+    ownsInfo = true;
+    successProbability = other.successProbability;
+    splitDimension = other.splitDimension;
+    majorityClass = other.majorityClass;
+    majorityProbability = other.majorityProbability;
+    categoricalSplit = other.categoricalSplit;
+    numericSplit = other.numericSplit;
+
+    // Copy each of the children.
+    for (size_t i = 0; i < other.children.size(); ++i)
+    {
+      children.push_back(new HoeffdingTree(*other.children[i]));
+
+      // Delete copied datasetInfo and dimension mappings.
+      delete children[i]->datasetInfo;
+      children[i]->datasetInfo = this->datasetInfo;
+      children[i]->ownsInfo = false;
+
+      delete children[i]->dimensionMappings;
+      children[i]->dimensionMappings = this->dimensionMappings;
+      children[i]->ownsMappings = false;
+    }
+  }
+  return *this;
+}
+
+// Move assignment operator.
+template<typename FitnessFunction,
+         template<typename> class NumericSplitType,
+         template<typename> class CategoricalSplitType>
+HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>&
+    HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>::
+    operator=(HoeffdingTree&& other)
+{
+  if (this != &other)
+  {
+    numericSplits = std::move(other.numericSplits);
+    categoricalSplits = std::move(other.categoricalSplits);
+    dimensionMappings = other.dimensionMappings;
+    ownsMappings = true;
+    numSamples = other.numSamples;
+    numClasses = other.numClasses;
+    maxSamples = other.maxSamples;
+    checkInterval = other.checkInterval;
+    minSamples = other.minSamples;
+    datasetInfo = other.datasetInfo;
+    ownsInfo = true;
+    successProbability = other.successProbability;
+    splitDimension = other.splitDimension;
+    majorityClass = other.majorityClass;
+    majorityProbability = other.majorityProbability;
+    categoricalSplit = std::move(other.categoricalSplit);
+    numericSplit = std::move(other.numericSplit);
+
+    // Remove pointers.
+    other.dimensionMappings = nullptr;
+    other.datasetInfo = nullptr;
+
+    // Reset primary type variables.
+    other.numSamples = 0;
+    other.numClasses = 0;
+    other.checkInterval = 0;
+    other.minSamples = 0;
+    other.successProbability = 0.0;
+    other.splitDimension = 0;
+    other.majorityClass = 0;
+    other.majorityProbability = 0.0;
+  }
+  return *this;
+}
+
+
 template<typename FitnessFunction,
          template<typename> class NumericSplitType,
          template<typename> class CategoricalSplitType>
@@ -238,7 +428,6 @@ HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>::
     delete children[i];
 }
 
-//! Train on a set of points.
 template<typename FitnessFunction,
          template<typename> class NumericSplitType,
          template<typename> class CategoricalSplitType>
@@ -249,74 +438,69 @@ void HoeffdingTree<
     CategoricalSplitType
 >::Train(const MatType& data,
          const arma::Row<size_t>& labels,
-         const bool batchTraining)
+         const size_t numClasses,
+         const bool batchTraining,
+         const std::optional<double> successProbability,
+         const std::optional<size_t> maxSamples,
+         const std::optional<size_t> checkInterval)
 {
-  if (batchTraining)
-  {
-    // Pass all the points through the nodes, and then split only after that.
-    checkInterval = data.n_cols; // Only split on the last sample.
-    // Don't split if there are fewer than five points.
-    size_t oldMaxSamples = maxSamples;
-    maxSamples = std::max(size_t(data.n_cols - 1), size_t(5));
-    for (size_t i = 0; i < data.n_cols; ++i)
-      Train(data.col(i), labels[i]);
-    maxSamples = oldMaxSamples;
+  Train(data, labels, numClasses, batchTraining,
+      (successProbability.has_value()) ? successProbability.value() :
+          this->successProbability,
+      (maxSamples.has_value()) ? maxSamples.value() : this->maxSamples,
+      (checkInterval.has_value()) ? checkInterval.value() : this->checkInterval,
+          this->minSamples);
+}
 
-    // Now, if we did split, find out which points go to which child, and
-    // perform the same batch training.
-    if (children.size() > 0)
-    {
-      // We need to create a vector of indices that represent the points that
-      // must go to each child, so we need children.size() vectors, but we don't
-      // know how long they will be.  Therefore, we will create vectors each of
-      // size data.n_cols, but will probably not use all the memory we
-      // allocated, and then pass subvectors to the submat() function.
-      std::vector<arma::uvec> indices(children.size(), arma::uvec(data.n_cols));
-      arma::Col<size_t> counts =
-          arma::zeros<arma::Col<size_t>>(children.size());
+template<typename FitnessFunction,
+         template<typename> class NumericSplitType,
+         template<typename> class CategoricalSplitType>
+template<typename MatType>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::Train(const MatType& data,
+         const arma::Row<size_t>& labels,
+         const size_t numClasses,
+         const bool batchTraining,
+         const double successProbability,
+         const size_t maxSamples,
+         const size_t checkInterval,
+         const size_t minSamples)
+{
+  this->successProbability = successProbability;
+  this->maxSamples = maxSamples;
+  this->checkInterval = checkInterval;
+  this->minSamples = minSamples;
 
-      for (size_t i = 0; i < data.n_cols; ++i)
-      {
-        size_t direction = CalculateDirection(data.col(i));
-        size_t currentIndex = counts[direction];
-        indices[direction][currentIndex] = i;
-        counts[direction]++;
-      }
+  // We need to reset the tree either if the user asked for it, or if they
+  // passed data whose dimensionality is different than our datasetInfo object.
+  if (data.n_rows != datasetInfo->Dimensionality() ||
+      (numClasses != 0 && numClasses != this->numClasses))
+  {
+    // Create a new datasetInfo, which assumes that all features are numeric.
+    if (ownsInfo)
+      delete datasetInfo;
+    datasetInfo = new data::DatasetInfo(data.n_rows);
+    ownsInfo = true;
 
-      // Now pass each of these submatrices to the children to perform
-      // batch-mode training.
-      for (size_t i = 0; i < children.size(); ++i)
-      {
-        // If we don't have any points that go to the child in question, don't
-        // train that child.
-        if (counts[i] == 0)
-          continue;
+    // Set the number of classes correctly.
+    if (numClasses != 0)
+      this->numClasses = numClasses;
 
-        // The submatrix here is non-contiguous, but I think this will be faster
-        // than copying the points to an ordered state.  We still have to
-        // assemble the labels vector, though.
-        arma::Row<size_t> childLabels = labels.cols(
-            indices[i].subvec(0, counts[i] - 1));
+    if (this->numClasses == 0)
+    {
+      throw std::invalid_argument("HoeffdingTree::Train(): must specify number "
+          "of classes!");
+    }
 
-        // Unfortunately, limitations of Armadillo's non-contiguous subviews
-        // prohibits us from successfully passing the non-contiguous subview to
-        // Train(), since the col() function is not provided.  So,
-        // unfortunately, instead, we'll just extract the non-contiguous
-        // submatrix.
-        MatType childData = data.cols(indices[i].subvec(0, counts[i] - 1));
-        children[i]->Train(childData, childLabels, true);
-      }
-    }
+    ResetTree();
   }
-  else
-  {
-    // We aren't training in batch mode; loop through the points.
-    for (size_t i = 0; i < data.n_cols; ++i)
-      Train(data.col(i), labels[i]);
-  }
+
+  TrainInternal(data, labels, batchTraining);
 }
 
-//! Train on a set of points.
 template<typename FitnessFunction,
          template<typename> class NumericSplitType,
          template<typename> class CategoricalSplitType>
@@ -328,48 +512,70 @@ void HoeffdingTree<
 >::Train(const MatType& data,
          const data::DatasetInfo& info,
          const arma::Row<size_t>& labels,
-         const bool batchTraining)
+         const size_t numClasses,
+         const bool batchTraining,
+         const std::optional<double> successProbability,
+         const std::optional<size_t> maxSamples,
+         const std::optional<size_t> checkInterval)
 {
-  // Take over new DatasetInfo.
-  if (ownsInfo)
-    delete datasetInfo;
-  datasetInfo = &info;
-  ownsInfo = false;
+  Train(data, info, labels, numClasses, batchTraining,
+      (successProbability.has_value()) ? successProbability.value() :
+          this->successProbability,
+      (maxSamples.has_value()) ? maxSamples.value() : this->maxSamples,
+      (checkInterval.has_value()) ? checkInterval.value() : this->checkInterval,
+          this->minSamples);
+}
 
-  // Generate mappings.
-  if (ownsMappings)
-    delete dimensionMappings;
+template<typename FitnessFunction,
+         template<typename> class NumericSplitType,
+         template<typename> class CategoricalSplitType>
+template<typename MatType>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::Train(const MatType& data,
+         const data::DatasetInfo& info,
+         const arma::Row<size_t>& labels,
+         const size_t numClasses,
+         const bool batchTraining,
+         const double successProbability,
+         const size_t maxSamples,
+         const size_t checkInterval,
+         const size_t minSamples)
+{
+  this->successProbability = successProbability;
+  this->maxSamples = maxSamples;
+  this->checkInterval = checkInterval;
+  this->minSamples = minSamples;
 
-  const CategoricalSplitType<FitnessFunction> categoricalSplitIn(0, 0);
-  const NumericSplitType<FitnessFunction>& numericSplitIn(0);
-
-  dimensionMappings =
-      new std::unordered_map<size_t, std::pair<size_t, size_t>>();
-  for (size_t i = 0; i < datasetInfo->Dimensionality(); ++i)
+  // We need to reset the tree either if the user asked for it, or if they
+  // passed data whose dimensionality is different than our datasetInfo object.
+  if (data.n_rows != datasetInfo->Dimensionality() ||
+      (numClasses != 0 && numClasses != this->numClasses))
   {
-    if (datasetInfo->Type(i) == data::Datatype::categorical)
+    // Set the number of classes correctly.
+    if (numClasses != 0)
+      this->numClasses = numClasses;
+
+    if (this->numClasses == 0)
     {
-      categoricalSplits.push_back(CategoricalSplitType<FitnessFunction>(
-          datasetInfo->NumMappings(i), numClasses, categoricalSplitIn));
-      (*dimensionMappings)[i] = std::make_pair(data::Datatype::categorical,
-          categoricalSplits.size() - 1);
-    }
-    else
-    {
-      numericSplits.push_back(NumericSplitType<FitnessFunction>(numClasses,
-          numericSplitIn));
-      (*dimensionMappings)[i] = std::make_pair(data::Datatype::numeric,
-          numericSplits.size() - 1);
+      throw std::invalid_argument("HoeffdingTree::Train(): must specify number "
+          "of classes!");
     }
+
+    Reset(info, this->numClasses);
+  }
+  else if (datasetInfo != &info)
+  {
+    // Take over new DatasetInfo.
+    if (ownsInfo)
+      delete datasetInfo;
+    datasetInfo = &info;
+    ownsInfo = false;
   }
 
-  // Remove any old children.
-  for (size_t i = 0; i < children.size(); ++i)
-    delete children[i];
-  children.clear();
-
-  // Now train.
-  Train(data, labels, batchTraining);
+  TrainInternal(data, labels, batchTraining);
 }
 
 //! Train on one point.
@@ -783,6 +989,62 @@ void HoeffdingTree<
   categoricalSplits.clear();
 }
 
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::Reset()
+{
+  ResetTree();
+}
+
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::Reset(const size_t dimensionality, const size_t numClasses)
+{
+  if (ownsInfo)
+    delete datasetInfo;
+  datasetInfo = new data::DatasetInfo(dimensionality); // All features numeric.
+  ownsInfo = true;
+
+  this->numClasses = numClasses;
+
+  ResetTree();
+}
+
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::Reset(const data::DatasetInfo& info, const size_t numClasses)
+{
+  if (ownsInfo)
+    delete datasetInfo;
+  datasetInfo = &info;
+  ownsInfo = false;
+
+  this->numClasses = numClasses;
+
+  ResetTree();
+}
+
 template<
     typename FitnessFunction,
     template<typename> class NumericSplitType,
@@ -793,22 +1055,23 @@ void HoeffdingTree<
     FitnessFunction,
     NumericSplitType,
     CategoricalSplitType
->::serialize(Archive& ar, const unsigned int /* version */)
+>::serialize(Archive& ar, const uint32_t /* version */)
 {
-  ar & BOOST_SERIALIZATION_NVP(splitDimension);
+  ar(CEREAL_NVP(splitDimension));
 
   // Clear memory for the mappings if necessary.
-  if (Archive::is_loading::value && ownsMappings && dimensionMappings)
+  if (cereal::is_loading<Archive>() && ownsMappings && dimensionMappings)
     delete dimensionMappings;
 
-  ar & BOOST_SERIALIZATION_NVP(dimensionMappings);
+  ar(CEREAL_POINTER(dimensionMappings));
 
   // Special handling for const object.
   data::DatasetInfo* d = NULL;
-  if (Archive::is_saving::value)
+  if (cereal::is_saving<Archive>())
     d = const_cast<data::DatasetInfo*>(datasetInfo);
-  ar & BOOST_SERIALIZATION_NVP(d);
-  if (Archive::is_loading::value)
+  ar(CEREAL_POINTER(d));
+
+  if (cereal::is_loading<Archive>())
   {
     if (datasetInfo && ownsInfo)
       delete datasetInfo;
@@ -823,22 +1086,22 @@ void HoeffdingTree<
     children.clear();
   }
 
-  ar & BOOST_SERIALIZATION_NVP(majorityClass);
-  ar & BOOST_SERIALIZATION_NVP(majorityProbability);
+  ar(CEREAL_NVP(majorityClass));
+  ar(CEREAL_NVP(majorityProbability));
 
   // Depending on whether or not we have split yet, we may need to save
   // different things.
   if (splitDimension == size_t(-1))
   {
     // We have not yet split.  So we have to serialize the splits.
-    ar & BOOST_SERIALIZATION_NVP(numSamples);
-    ar & BOOST_SERIALIZATION_NVP(numClasses);
-    ar & BOOST_SERIALIZATION_NVP(maxSamples);
-    ar & BOOST_SERIALIZATION_NVP(successProbability);
+    ar(CEREAL_NVP(numSamples));
+    ar(CEREAL_NVP(numClasses));
+    ar(CEREAL_NVP(maxSamples));
+    ar(CEREAL_NVP(successProbability));
 
     // Serialize the splits, but not if we haven't seen any samples yet (in
     // which case we can just reinitialize).
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       // Re-initialize all of the splits.
       numericSplits.clear();
@@ -865,23 +1128,23 @@ void HoeffdingTree<
       return;
 
     // Serialize numeric splits.
-    ar & BOOST_SERIALIZATION_NVP(numericSplits);
+    ar(CEREAL_NVP(numericSplits));
 
     // Serialize categorical splits.
-    ar & BOOST_SERIALIZATION_NVP(categoricalSplits);
+    ar(CEREAL_NVP(categoricalSplits));
   }
   else
   {
     // We have split, so we only need to save the split and the children.
     if (datasetInfo->Type(splitDimension) == data::Datatype::categorical)
-      ar & BOOST_SERIALIZATION_NVP(categoricalSplit);
+      ar(CEREAL_NVP(categoricalSplit));
     else
-      ar & BOOST_SERIALIZATION_NVP(numericSplit);
+      ar(CEREAL_NVP(numericSplit));
 
     // Serialize the children, because we have split.
-    ar & BOOST_SERIALIZATION_NVP(children);
+      ar(CEREAL_VECTOR_POINTER(children));
 
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       for (size_t i = 0; i < children.size(); ++i)
       {
@@ -903,7 +1166,151 @@ void HoeffdingTree<
   }
 }
 
-} // namespace tree
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+template<typename MatType>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::TrainInternal(const MatType& data,
+                 const arma::Row<size_t>& labels,
+                 const bool batchTraining)
+{
+  if (batchTraining)
+  {
+    // Pass all the points through the nodes, and then split only after that.
+    checkInterval = data.n_cols; // Only split on the last sample.
+    // Don't split if there are fewer than five points.
+    size_t oldMaxSamples = maxSamples;
+    maxSamples = std::max(size_t(data.n_cols - 1), size_t(5));
+    for (size_t i = 0; i < data.n_cols; ++i)
+      Train(data.col(i), labels[i]);
+    maxSamples = oldMaxSamples;
+
+    // Now, if we did split, find out which points go to which child, and
+    // perform the same batch training.
+    if (children.size() > 0)
+    {
+      // We need to create a vector of indices that represent the points that
+      // must go to each child, so we need children.size() vectors, but we don't
+      // know how long they will be.  Therefore, we will create vectors each of
+      // size data.n_cols, but will probably not use all the memory we
+      // allocated, and then pass subvectors to the submat() function.
+      std::vector<arma::uvec> indices(children.size(), arma::uvec(data.n_cols));
+      arma::Col<size_t> counts =
+          zeros<arma::Col<size_t>>(children.size());
+
+      for (size_t i = 0; i < data.n_cols; ++i)
+      {
+        size_t direction = CalculateDirection(data.col(i));
+        size_t currentIndex = counts[direction];
+        indices[direction][currentIndex] = i;
+        counts[direction]++;
+      }
+
+      // Now pass each of these submatrices to the children to perform
+      // batch-mode training.
+      for (size_t i = 0; i < children.size(); ++i)
+      {
+        // If we don't have any points that go to the child in question, don't
+        // train that child.
+        if (counts[i] == 0)
+          continue;
+
+        // The submatrix here is non-contiguous, but I think this will be faster
+        // than copying the points to an ordered state.  We still have to
+        // assemble the labels vector, though.
+        arma::Row<size_t> childLabels = labels.cols(
+            indices[i].subvec(0, counts[i] - 1));
+
+        // Unfortunately, limitations of Armadillo's non-contiguous subviews
+        // prohibits us from successfully passing the non-contiguous subview to
+        // Train(), since the col() function is not provided.  So,
+        // unfortunately, instead, we'll just extract the non-contiguous
+        // submatrix.
+        //
+        // I'd rather be able to use:
+        //
+        // arma::Mat<typename MatType::elem_type> childData =
+        //     data.cols(indices[i].subvec(0, counts[i] - 1));
+        //
+        // but this isn't currently supported by Armadillo.
+        arma::Mat<typename MatType::elem_type> childData(data.n_rows,
+            counts[i]);
+        for (size_t j = 0; j < counts[i]; ++j)
+          childData.col(j) = data.col(indices[i][j]);
+
+        children[i]->Train(childData, childLabels, numClasses, true);
+      }
+    }
+  }
+  else
+  {
+    // We aren't training in batch mode; loop through the points.
+    for (size_t i = 0; i < data.n_cols; ++i)
+      Train(data.col(i), labels[i]);
+  }
+}
+
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::ResetTree(const CategoricalSplitType<FitnessFunction>& categoricalSplitIn,
+             const NumericSplitType<FitnessFunction>& numericSplitIn)
+{
+  // Generate mappings.
+  if (ownsMappings)
+    delete dimensionMappings;
+
+  categoricalSplits.clear();
+  numericSplits.clear();
+
+  dimensionMappings =
+      new std::unordered_map<size_t, std::pair<size_t, size_t>>();
+  ownsMappings = true;
+  for (size_t i = 0; i < datasetInfo->Dimensionality(); ++i)
+  {
+    if (datasetInfo->Type(i) == data::Datatype::categorical)
+    {
+      categoricalSplits.push_back(CategoricalSplitType<FitnessFunction>(
+          datasetInfo->NumMappings(i), numClasses, categoricalSplitIn));
+      (*dimensionMappings)[i] = std::make_pair(data::Datatype::categorical,
+          categoricalSplits.size() - 1);
+    }
+    else
+    {
+      numericSplits.push_back(NumericSplitType<FitnessFunction>(numClasses,
+          numericSplitIn));
+      (*dimensionMappings)[i] = std::make_pair(data::Datatype::numeric,
+          numericSplits.size() - 1);
+    }
+  }
+
+  // Clear children.
+  for (size_t i = 0; i < children.size(); ++i)
+    delete children[i];
+  children.clear();
+
+  // Reset statistics.
+  numSamples = 0;
+  splitDimension = size_t(-1);
+  majorityClass = 0;
+  majorityProbability = 0.0;
+  categoricalSplit =
+      typename CategoricalSplitType<FitnessFunction>::SplitInfo(0);
+  numericSplit = typename NumericSplitType<FitnessFunction>::SplitInfo();
+}
+
 } // namespace mlpack
 
 #endif
