@@ -16,13 +16,12 @@
 #include <mlpack/core/tree/traversal_info.hpp>
 
 namespace mlpack {
-namespace kde {
 
 /**
  * A dual-tree traversal Rules class for kernel density estimation.  This
  * contains the Score() and BaseCase() implementations.
  */
-template<typename MetricType, typename KernelType, typename TreeType>
+template<typename DistanceType, typename KernelType, typename TreeType>
 class KDERules
 {
  public:
@@ -39,7 +38,7 @@ class KDERules
    * @param initialSampleSize Initial size of the Monte Carlo samples.
    * @param mcAccessCoef Access coefficient for Monte Carlo estimations.
    * @param mcBreakCoef Break coefficient for Monte Carlo estimations.
-   * @param metric Instantiated metric.
+   * @param distance Instantiated distance metric.
    * @param kernel Instantiated kernel.
    * @param monteCarlo If true Monte Carlo estimations will be applied when
    *                   possible.
@@ -55,7 +54,7 @@ class KDERules
            const size_t initialSampleSize,
            const double mcAccessCoef,
            const double mcBreakCoef,
-           MetricType& metric,
+           DistanceType& distance,
            KernelType& kernel,
            const bool monteCarlo,
            const bool sameSet);
@@ -79,7 +78,7 @@ class KDERules
                  TreeType& referenceNode,
                  const double oldScore) const;
 
-  typedef typename tree::TraversalInfo<TreeType> TraversalInfoType;
+  using TraversalInfoType = mlpack::TraversalInfo<TreeType>;
 
   //! Get traversal information.
   const TraversalInfoType& TraversalInfo() const { return traversalInfo; }
@@ -93,6 +92,10 @@ class KDERules
   //! Get the number of scores.
   size_t Scores() const { return scores; }
 
+  //! Get the minimum number of base cases we need to perform to have acceptable
+  //! results.
+  size_t MinimumBaseCases() const { return 0; }
+
  private:
   //! Evaluate kernel value of 2 points given their indexes.
   double EvaluateKernel(const size_t queryIndex,
@@ -136,8 +139,8 @@ class KDERules
   //! is the limit before Monte Carlo estimation recurses.
   const double mcBreakCoef;
 
-  //! Instantiated metric.
-  MetricType& metric;
+  //! Instantiated distance metric.
+  DistanceType& distance;
 
   //! Instantiated kernel.
   KernelType& kernel;
@@ -156,7 +159,7 @@ class KDERules
 
   //! Whether the kernel used for the rule is the Gaussian Kernel.
   constexpr static bool kernelIsGaussian =
-      std::is_same<KernelType, kernel::GaussianKernel>::value;
+      std::is_same_v<KernelType, GaussianKernel>;
 
   //! Absolute error tolerance available for each reference point.
   const double absErrorTol;
@@ -207,7 +210,7 @@ class KDECleanRules
                  TreeType& /* referenceNode*/ ,
                  const double oldScore) const { return oldScore; }
 
-  typedef typename tree::TraversalInfo<TreeType> TraversalInfoType;
+  using TraversalInfoType = mlpack::TraversalInfo<TreeType>;
 
   //! Get traversal information.
   const TraversalInfoType& TraversalInfo() const { return traversalInfo; }
@@ -220,7 +223,6 @@ class KDECleanRules
   TraversalInfoType traversalInfo;
 };
 
-} // namespace kde
 } // namespace mlpack
 
 // Include implementation.
