@@ -18,7 +18,6 @@
 #include <mlpack/methods/block_krylov_svd/randomized_block_krylov_svd.hpp>
 
 namespace mlpack {
-namespace pca {
 
 /**
  * Implementation of the randomized block krylov SVD policy.
@@ -53,28 +52,29 @@ class RandomizedBlockKrylovSVDPolicy
    * @param eigvec Matrix to put eigenvectors (loadings) into.
    * @param rank Rank of the decomposition.
    */
-  void Apply(const arma::mat& data,
-             const arma::mat& centeredData,
-             arma::mat& transformedData,
-             arma::vec& eigVal,
-             arma::mat& eigvec,
+  template<typename InMatType, typename MatType, typename VecType>
+  void Apply(const InMatType& /* data */,
+             const MatType& centeredData,
+             MatType& transformedData,
+             VecType& eigVal,
+             MatType& eigvec,
              const size_t rank)
   {
-    // This matrix will store the right singular values; we do not need them.
-    arma::mat v;
+    // This matrix will store the right singular vectors; we do not need them.
+    MatType v;
 
     // Do singular value decomposition using the randomized block krylov SVD
     // algorithm.
-    svd::RandomizedBlockKrylovSVD rsvd(maxIterations, blockSize);
+    RandomizedBlockKrylovSVD rsvd(maxIterations, blockSize);
     rsvd.Apply(centeredData, eigvec, eigVal, v, rank);
 
     // Now we must square the singular values to get the eigenvalues.
     // In addition we must divide by the number of points, because the
     // covariance matrix is X * X' / (N - 1).
-    eigVal %= eigVal / (data.n_cols - 1);
+    eigVal %= eigVal / (centeredData.n_cols - 1);
 
     // Project the samples to the principals.
-    transformedData = arma::trans(eigvec) * centeredData;
+    transformedData = trans(eigvec) * centeredData;
   }
 
   //! Get the number of iterations for the power method.
@@ -95,7 +95,6 @@ class RandomizedBlockKrylovSVDPolicy
   size_t blockSize;
 };
 
-} // namespace pca
 } // namespace mlpack
 
 #endif
