@@ -9,13 +9,15 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/io.hpp>
+#include <mlpack/core.hpp>
+
+#undef BINDING_NAME
+#define BINDING_NAME preprocess_binarize
+
 #include <mlpack/core/util/mlpack_main.hpp>
-#include <mlpack/core/data/binarize.hpp>
 
 // Program Name.
-BINDING_NAME("Binarize Data");
+BINDING_USER_NAME("Binarize Data");
 
 // Short description.
 BINDING_SHORT_DESC(
@@ -55,7 +57,9 @@ BINDING_EXAMPLE(
 
 // See also...
 BINDING_SEE_ALSO("@preprocess_describe", "#preprocess_describe");
+#if BINDING_TYPE == BINDING_TYPE_CLI
 BINDING_SEE_ALSO("@preprocess_imputer", "#preprocess_imputer");
+#endif
 BINDING_SEE_ALSO("@preprocess_split", "#preprocess_split");
 
 // Define parameters for data.
@@ -72,41 +76,42 @@ using namespace mlpack::util;
 using namespace arma;
 using namespace std;
 
-static void mlpackMain()
+void BINDING_FUNCTION(util::Params& params, util::Timers& timers)
 {
-  const size_t dimension = (size_t) IO::GetParam<int>("dimension");
-  const double threshold = IO::GetParam<double>("threshold");
+  const size_t dimension = (size_t) params.Get<int>("dimension");
+  const double threshold = params.Get<double>("threshold");
 
   // Check on data parameters.
-  if (!IO::HasParam("dimension"))
+  if (!params.Has("dimension"))
   {
     Log::Warn << "You did not specify " << PRINT_PARAM_STRING("dimension")
         << ", so the program will perform binarization on every dimension."
         << endl;
   }
 
-  if (!IO::HasParam("threshold"))
+  if (!params.Has("threshold"))
   {
     Log::Warn << "You did not specify " << PRINT_PARAM_STRING("threshold")
         << ", so the threshold will be automatically set to '0.0'." << endl;
   }
 
-  RequireAtLeastOnePassed({ "output" }, false, "no output will be saved");
+  RequireAtLeastOnePassed(params, { "output" }, false,
+      "no output will be saved");
 
   // Load the data.
-  arma::mat input = std::move(IO::GetParam<arma::mat>("input"));
+  arma::mat input = std::move(params.Get<arma::mat>("input"));
   arma::mat output;
 
-  RequireParamValue<int>("dimension", [](int x) { return x >= 0; }, true,
-      "dimension to binarize must be nonnegative");
+  RequireParamValue<int>(params, "dimension", [](int x) { return x >= 0; },
+      true, "dimension to binarize must be nonnegative");
   std::ostringstream error;
   error << "dimension to binarize must be less than the number of dimensions "
       << "of the input data (" << input.n_rows << ")";
-  RequireParamValue<int>("dimension",
+  RequireParamValue<int>(params, "dimension",
       [input](int x) { return size_t(x) < input.n_rows; }, true, error.str());
 
-  Timer::Start("binarize");
-  if (IO::HasParam("dimension"))
+  timers.Start("binarize");
+  if (params.Has("dimension"))
   {
     data::Binarize<double>(input, output, threshold, dimension);
   }
@@ -115,8 +120,8 @@ static void mlpackMain()
     // Binarize the whole dataset.
     data::Binarize<double>(input, output, threshold);
   }
-  Timer::Stop("binarize");
+  timers.Stop("binarize");
 
-  if (IO::HasParam("output"))
-    IO::GetParam<arma::mat>("output") = std::move(output);
+  if (params.Has("output"))
+    params.Get<arma::mat>("output") = std::move(output);
 }
