@@ -78,7 +78,8 @@ void CheckDerivativeCorrect(const arma::colvec input,
   ActivationFunction::Deriv(input, outputs, derivatives);
   for (size_t i = 0; i < derivatives.n_elem; ++i)
   {
-    REQUIRE(derivatives.at(i) == Approx(target.at(i)).epsilon(1e-5).margin(1e-15));
+    REQUIRE(derivatives.at(i) ==
+        Approx(target.at(i)).epsilon(1e-5).margin(1e-15));
   }
 }
 
@@ -107,7 +108,8 @@ void CheckInverseCorrect(const arma::colvec input)
 
   for (size_t i = 0; i < input.n_elem; ++i)
   {
-    REQUIRE(activations.at(i) == Approx(input.at(i)).epsilon(1e-5).margin(1e-15));
+    REQUIRE(activations.at(i) ==
+        Approx(input.at(i)).epsilon(1e-5).margin(1e-15));
   }
 }
 
@@ -277,7 +279,7 @@ TEST_CASE("SELUFunctionNormalizedTest", "[ActivationFunctionsTest]")
 {
   arma::mat input = arma::randn<arma::mat>(1000, 1);
   arma::mat output(arma::size(input));
-  
+
   SELU selu;
   selu.Forward(input, output);
 
@@ -293,10 +295,10 @@ TEST_CASE("SELUFunctionNormalizedTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("SELUFunctionUnnormalizedTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec input("5.96402758 0.9966824 0.99975321 1 \
-                            7.76159416 -0.76159416 0.96402758 8");
+  const arma::colvec input("5.96402758 0.9966824 0.99975321 1 "
+                           "7.76159416 -0.76159416 0.96402758 8");
   arma::mat output(arma::size(input));
-  
+
   SELU selu;
   selu.Forward(input, output);
 
@@ -323,7 +325,7 @@ TEST_CASE("SELUFunctionDerivativeTest", "[ActivationFunctionsTest]")
 
   selu.Forward(input, activations);
   selu.Backward(input, activations, error, derivatives);
-  
+
   REQUIRE(arma::as_scalar(arma::abs(arma::mean(derivatives) -
       selu.Lambda())) <= 10e-4);
 
@@ -341,18 +343,19 @@ TEST_CASE("SELUFunctionDerivativeTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("TanhFunctionTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec desiredActivations("-0.96402758 0.9966824 0.99975321 -1 \
-                                         0.76159416 -0.76159416 0.96402758 0");
+  const arma::colvec desiredActivations("-0.96402758 0.9966824 0.99975321 -1 "
+                                        "0.76159416 -0.76159416 0.96402758 0");
 
-  const arma::colvec desiredDerivatives("0.07065082 0.00662419 0.00049352 0 \
-                                         0.41997434 0.41997434 0.07065082 1");
+  const arma::colvec desiredDerivatives("0.07065082 0.00662419 0.00049352 0 "
+                                        "0.41997434 0.41997434 0.07065082 1");
 
   CheckActivationCorrect<TanhFunction>(activationData, desiredActivations);
   CheckDerivativeCorrect<TanhFunction>(activationData, desiredDerivatives);
   CheckInverseCorrect<TanhFunction>(desiredActivations);
-  
+
   arma::mat inputTemp(desiredActivations.n_elem, 1);
-  double maxRelativeError = ActivationJacobianTest<TanhFunction>(inputTemp,-2,2);
+  double maxRelativeError = ActivationJacobianTest<TanhFunction>(inputTemp, -2,
+      2);
   REQUIRE(maxRelativeError <= 1e-3);
 }
 
@@ -361,14 +364,14 @@ TEST_CASE("TanhFunctionTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("LogisticFunctionTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec desiredActivations("1.19202922e-01 9.60834277e-01 \
-                                         9.89013057e-01 3.04574e-44 \
-                                         7.31058579e-01 2.68941421e-01 \
-                                         8.80797078e-01 0.5");
+  const arma::colvec desiredActivations("1.19202922e-01 9.60834277e-01 "
+                                        "9.89013057e-01 3.04574e-44 "
+                                        "7.31058579e-01 2.68941421e-01 "
+                                        "8.80797078e-01 0.5");
 
-  const arma::colvec desiredDerivatives("0.10499359 0.03763177 0.01086623 \
-                                         3.04574e-44 0.19661193 0.19661193 \
-                                         0.10499359 0.25");
+  const arma::colvec desiredDerivatives("0.10499359 0.03763177 0.01086623 "
+                                        "3.04574e-44 0.19661193 0.19661193 "
+                                        "0.10499359 0.25");
 
   CheckActivationCorrect<LogisticFunction>(activationData, desiredActivations);
   CheckDerivativeCorrect<LogisticFunction>(activationData,
@@ -381,11 +384,11 @@ TEST_CASE("LogisticFunctionTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("SoftsignFunctionTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec desiredActivations("-0.66666667 0.76190476 0.81818182 \
-                                         -0.99011858 0.5 -0.5 0.66666667 0");
+  const arma::colvec desiredActivations("-0.66666667 0.76190476 0.81818182 "
+                                        "-0.99011858 0.5 -0.5 0.66666667 0");
 
-  const arma::colvec desiredDerivatives("0.11111111 0.05668934 0.03305785 \
-                                         9.7642e-05 0.25 0.25 0.11111111 1");
+  const arma::colvec desiredDerivatives("0.11111111 0.05668934 0.03305785 "
+                                        "9.7642e-05 0.25 0.25 0.11111111 1");
 
   CheckActivationCorrect<SoftsignFunction>(activationData, desiredActivations);
   CheckDerivativeCorrect<SoftsignFunction>(activationData,
@@ -393,7 +396,8 @@ TEST_CASE("SoftsignFunctionTest", "[ActivationFunctionsTest]")
   CheckInverseCorrect<SoftsignFunction>(desiredActivations);
 
   arma::mat inputTemp(desiredActivations.n_elem, 1);
-  double maxRelativeError = ActivationJacobianTest<SoftsignFunction>(inputTemp,-1,1);
+  double maxRelativeError = ActivationJacobianTest<SoftsignFunction>(inputTemp,
+      -1, 1);
   REQUIRE(maxRelativeError <= 1e-3);
 }
 
@@ -423,8 +427,9 @@ TEST_CASE("RectifierFunctionTest", "[ActivationFunctionsTest]")
                                             desiredDerivatives);
 
   arma::mat inputTemp(desiredActivations.n_elem, 1);
-  double maxRelativeError = ActivationJacobianTest<RectifierFunction>(inputTemp,-4,4);
-  REQUIRE(maxRelativeError <= 1e-3);  
+  double maxRelativeError = ActivationJacobianTest<RectifierFunction>(inputTemp,
+      -4, 4);
+  REQUIRE(maxRelativeError <= 1e-3);
 }
 
 /**
@@ -432,11 +437,11 @@ TEST_CASE("RectifierFunctionTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("LeakyReLUFunctionTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec desiredActivations("-0.06 3.2 4.5 -3.006 \
-                                         1 -0.03 2 0");
+  const arma::colvec desiredActivations("-0.06 3.2 4.5 -3.006 "
+                                        "1 -0.03 2 0");
 
-  const arma::colvec desiredDerivatives("0.03 1 1 0.03 \
-                                         1 0.03 1 1");
+  const arma::colvec desiredDerivatives("0.03 1 1 0.03 "
+                                        "1 0.03 1 1");
 
   CheckLeakyReLUActivationCorrect(activationData, desiredActivations);
   CheckLeakyReLUDerivativeCorrect(desiredActivations, desiredDerivatives);
@@ -447,11 +452,11 @@ TEST_CASE("LeakyReLUFunctionTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("ELUFunctionTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec desiredActivations("-0.86466471 3.2 4.5 -1.0 \
-                                         1 -0.63212055 2 0");
+  const arma::colvec desiredActivations("-0.86466471 3.2 4.5 -1.0 "
+                                        "1 -0.63212055 2 0");
 
-  const arma::colvec desiredDerivatives("0.13533529 1 1 0 \
-                                         1 0.36787945 1 1");
+  const arma::colvec desiredDerivatives("0.13533529 1 1 0 "
+                                        "1 0.36787945 1 1");
 
   CheckELUActivationCorrect(activationData, desiredActivations);
   CheckELUDerivativeCorrect(activationData, desiredDerivatives);
@@ -462,12 +467,12 @@ TEST_CASE("ELUFunctionTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("CELUFunctionTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec desiredActivations("-0.86466472 3.2 4.5 \
-                                         -1 1 -0.63212056 2 0");
+  const arma::colvec desiredActivations("-0.86466472 3.2 4.5 "
+                                        "-1 1 -0.63212056 2 0");
 
-  const arma::colvec desiredDerivatives("0.42119275 1 1 \
-                                         0.36787944 1 \
-                                         0.5314636 1 1");
+  const arma::colvec desiredDerivatives("0.42119275 1 1 "
+                                        "0.36787944 1 "
+                                        "0.5314636 1 1");
 
   CheckCELUActivationCorrect(activationData, desiredActivations);
   CheckCELUDerivativeCorrect(desiredActivations, desiredDerivatives);
@@ -480,17 +485,16 @@ TEST_CASE("SoftplusFunctionTest", "[ActivationFunctionsTest]")
 {
   const arma::colvec activationData("-2 3.2 4.5 -100.2 1 -1 2 0 1000 10000");
 
-  const arma::colvec desiredActivations("0.12692801 3.23995333 4.51104774 \
-                                         0 1.31326168 0.31326168 2.12692801 \
-                                         0.69314718 1000 10000");
+  const arma::colvec desiredActivations("0.12692801 3.23995333 4.51104774 "
+                                        "0 1.31326168 0.31326168 2.12692801 "
+                                        "0.69314718 1000 10000");
 
-  const arma::colvec desiredDerivatives("0.11920292 0.96083427 0.98901305 \
-                                        3.04574060e-44 0.73105857 0.26894142 \
-                                        0.88079707 0.5 1 1");
+  const arma::colvec desiredDerivatives("0.11920292 0.96083427 0.98901305 "
+                                        "3.04574060e-44 0.73105857 0.26894142 "
+                                        "0.88079707 0.5 1 1");
 
   CheckActivationCorrect<SoftplusFunction>(activationData, desiredActivations);
-  CheckDerivativeCorrect<SoftplusFunction>(activationData,
-                                           desiredDerivatives);
+  CheckDerivativeCorrect<SoftplusFunction>(activationData, desiredDerivatives);
   CheckInverseCorrect<SoftplusFunction>(desiredActivations);
 }
 
@@ -500,13 +504,8 @@ TEST_CASE("SoftplusFunctionTest", "[ActivationFunctionsTest]")
 TEST_CASE("HardSigmoidFunctionTest", "[ActivationFunctionsTest]")
 {
   // Hand-calculated values using Python interpreter.
-  const arma::colvec desiredActivations("0.1 1 1 \
-                                         0 0.7 0.3 \
-                                         0.9 0.5");
-
-  const arma::colvec desiredDerivatives("0.2 0.0 0.0 \
-                                         0.0 0.2 0.2 0.2\
-                                         0.2");
+  const arma::colvec desiredActivations("0.1 1 1 0 0.7 0.3 0.9 0.5");
+  const arma::colvec desiredDerivatives("0.2 0.0 0.0 0.0 0.2 0.2 0.2 0.2");
 
   CheckActivationCorrect<HardSigmoidFunction>(activationData,
                                               desiredActivations);
@@ -514,8 +513,9 @@ TEST_CASE("HardSigmoidFunctionTest", "[ActivationFunctionsTest]")
                                               desiredDerivatives);
 
   arma::mat inputTemp(desiredActivations.n_elem, 1);
-  double maxRelativeError = ActivationJacobianTest<HardSigmoidFunction>(inputTemp,-4,4);
-  REQUIRE(maxRelativeError <= 1e-3);  
+  double maxRelativeError = ActivationJacobianTest<HardSigmoidFunction>(
+      inputTemp, -4, 4);
+  REQUIRE(maxRelativeError <= 1e-3);
 }
 
 /**
@@ -525,14 +525,14 @@ TEST_CASE("MishFunctionTest", "[ActivationFunctionsTest]")
 {
   // Calculated using tfa.activations.mish().
   // where tfa is tensorflow_addons.
-  const arma::colvec desiredActivations("-0.25250152 3.1901977 \
-                                         4.498914 -3.05183208e-42 0.86509836 \
-                                         -0.30340138 1.943959 0");
+  const arma::colvec desiredActivations("-0.25250152 3.1901977 "
+                                        "4.498914 -3.05183208e-42 0.86509836 "
+                                        "-0.30340138 1.943959 0");
 
-  const arma::colvec desiredDerivatives("-0.10835509242 1.01574465162 \
-                                        1.00190704417 -3.05183208657e-42 \
-                                        1.0490362201 0.0592167558774 \
-                                        1.06931793428 0.6");
+  const arma::colvec desiredDerivatives("-0.10835509242 1.01574465162 "
+                                        "1.00190704417 -3.05183208657e-42 "
+                                        "1.0490362201 0.0592167558774 "
+                                        "1.06931793428 0.6");
 
   CheckActivationCorrect<MishFunction>(activationData,
                                        desiredActivations);
@@ -547,18 +547,16 @@ TEST_CASE("LiSHTFunctionTest", "[ActivationFunctionsTest]")
 {
   // Calculated using tfa.activations.LiSHT().
   // where tfa is tensorflow_addons.
-  const arma::colvec desiredActivations("1.928055 3.189384 \
-                                         4.4988894 100.2 0.7615942 \
-                                         0.7615942 1.9280552 0");
+  const arma::colvec desiredActivations("1.928055 3.189384 "
+                                        "4.4988894 100.2 0.7615942 "
+                                        "0.7615942 1.9280552 0");
 
-  const arma::colvec desiredDerivatives("-1.1053292 1.0178798 1.001974 \
-                                        -1.0 1.1815685 -1.1815685 1.1053292 \
-                                        0.0");
+  const arma::colvec desiredDerivatives("-1.1053292 1.0178798 1.001974 "
+                                        "-1.0 1.1815685 -1.1815685 1.1053292 "
+                                        "0.0");
 
-  CheckActivationCorrect<LiSHTFunction>(activationData,
-                                        desiredActivations);
-  CheckDerivativeCorrect<LiSHTFunction>(activationData,
-                                        desiredDerivatives);
+  CheckActivationCorrect<LiSHTFunction>(activationData, desiredActivations);
+  CheckDerivativeCorrect<LiSHTFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -567,17 +565,15 @@ TEST_CASE("LiSHTFunctionTest", "[ActivationFunctionsTest]")
 TEST_CASE("GELUFunctionTest", "[ActivationFunctionsTest]")
 {
   // Calculated using torch.nn.gelu().
-  const arma::colvec desiredActivations("-0.0454023 3.1981304 \
-                                         4.5 -0.0 0.84119199 \
-                                         -0.158808 1.954597694 0.0");
+  const arma::colvec desiredActivations("-0.0454023 3.1981304 "
+                                        "4.5 -0.0 0.84119199 "
+                                        "-0.158808 1.954597694 0.0");
 
-  const arma::colvec desiredDerivatives("-0.086099065 1.0064931 1.0000293 \
-                                        0 1.0829639 -0.0829639 1.0860991 0.5");
+  const arma::colvec desiredDerivatives("-0.086099065 1.0064931 1.0000293 "
+                                        "0 1.0829639 -0.0829639 1.0860991 0.5");
 
-  CheckActivationCorrect<GELUFunction>(activationData,
-                                       desiredActivations);
-  CheckDerivativeCorrect<GELUFunction>(activationData,
-                                       desiredDerivatives);
+  CheckActivationCorrect<GELUFunction>(activationData, desiredActivations);
+  CheckDerivativeCorrect<GELUFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -589,18 +585,16 @@ TEST_CASE("ElliotFunctionTest", "[ActivationFunctionsTest]")
 
   // Hand-calculated values.
   arma::colvec desiredActivation(
-      "-0.5 0.0 0.5454545454545454 0.6774193548387097 0.7368421052631579 \
-      0.5 -0.5238095238095238 -0.6666666666666666, -0.7560975609756099");
+      "-0.5 0.0 0.5454545454545454 0.6774193548387097 0.7368421052631579 "
+      "0.5 -0.5238095238095238 -0.6666666666666666, -0.7560975609756099");
 
   // Hand-calculated values.
   arma::colvec desiredDerivate(
-      "0.25 1.0 0.20661157024793392 0.10405827263267425 0.06925207756232689 \
-      0.25 0.22675736961451246 0.11111111111111113 0.05948839976204635");
+      "0.25 1.0 0.20661157024793392 0.10405827263267425 0.06925207756232689 "
+      "0.25 0.22675736961451246 0.11111111111111113 0.05948839976204635");
 
-  CheckActivationCorrect<ElliotFunction>(activationData
-                                                ,desiredActivation);
-  CheckDerivativeCorrect<ElliotFunction>(activationData
-                                                ,desiredDerivate);
+  CheckActivationCorrect<ElliotFunction>(activationData, desiredActivation);
+  CheckDerivativeCorrect<ElliotFunction>(activationData, desiredDerivate);
   arma::mat inputTemp(activationData.n_elem, 1);
   double maxRelativeError = ActivationJacobianTest<ElliotFunction>(inputTemp);
   REQUIRE(maxRelativeError <= 1e-3);
@@ -612,18 +606,16 @@ TEST_CASE("ElliotFunctionTest", "[ActivationFunctionsTest]")
 TEST_CASE("ElishFunctionTest", "[ActivationFunctionsTest]")
 {
   // Manually-calculated using python-numpy module.
-  const arma::colvec desiredActivations("-0.10307056 3.0746696 4.4505587 \
-                                         -3.0457406e-44 0.731058578 \
-                                         -0.1700034 1.76159415 0.0 ");
+  const arma::colvec desiredActivations("-0.10307056 3.0746696 4.4505587 "
+                                        "-3.0457406e-44 0.731058578 "
+                                        "-0.1700034 1.76159415 0.0 ");
 
-  const arma::colvec desiredDerivatives("-0.074651888 1.0812559 1.0379111 \
-                                        0.0 0.92767051 -0.025344425 1.0907842 \
-                                        0.5");
+  const arma::colvec desiredDerivatives("-0.074651888 1.0812559 1.0379111 "
+                                        "0.0 0.92767051 -0.025344425 1.0907842 "
+                                        "0.5");
 
-  CheckActivationCorrect<ElishFunction>(activationData,
-                                        desiredActivations);
-  CheckDerivativeCorrect<ElishFunction>(activationData,
-                                        desiredDerivatives);
+  CheckActivationCorrect<ElishFunction>(activationData, desiredActivations);
+  CheckDerivativeCorrect<ElishFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -632,16 +624,15 @@ TEST_CASE("ElishFunctionTest", "[ActivationFunctionsTest]")
 TEST_CASE("InverseQuadraticFunctionTest", "[ActivationFunctionsTest]")
 {
   // Hand-calculated values.
-  const arma::colvec desiredActivations("0.2 0.088968 0.0470588 \
-                                         9.95913e-05 0.5 0.5 \
-                                         0.2 1");
+  const arma::colvec desiredActivations("0.2 0.088968 0.0470588 "
+                                        "9.95913e-05 0.5 0.5 "
+                                        "0.2 1");
 
-  const arma::colvec desiredDerivatives("0.16 -0.05065792 -0.019930796 \
-                                        1.9876519e-06 -0.5 0.5 -0.16 0.0");
+  const arma::colvec desiredDerivatives("0.16 -0.05065792 -0.019930796 "
+                                        "1.9876519e-06 -0.5 0.5 -0.16 0.0");
 
   CheckActivationCorrect<InvQuadFunction>(activationData, desiredActivations);
-  CheckDerivativeCorrect<InvQuadFunction>(activationData,
-                                          desiredDerivatives);
+  CheckDerivativeCorrect<InvQuadFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -650,16 +641,11 @@ TEST_CASE("InverseQuadraticFunctionTest", "[ActivationFunctionsTest]")
 TEST_CASE("QuadraticFunctionTest", "[ActivationFunctionsTest]")
 {
   // Hand-calculated values.
-  const arma::colvec desiredActivations("4 10.24 20.25 \
-                                         10040 1 1 \
-                                         4 0");
-
-  const arma::colvec desiredDerivatives("-4.0 6.4 9.0 -200.4 \
-                                        2.0 -2.0 4.0 0.0");
+  const arma::colvec desiredActivations("4 10.24 20.25 10040 1 1 4 0");
+  const arma::colvec desiredDerivatives("-4.0 6.4 9.0 -200.4 2.0 -2.0 4.0 0.0");
 
   CheckActivationCorrect<QuadraticFunction>(activationData, desiredActivations);
-  CheckDerivativeCorrect<QuadraticFunction>(activationData,
-                                            desiredDerivatives);
+  CheckDerivativeCorrect<QuadraticFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -670,17 +656,16 @@ TEST_CASE("SplineFunctionTest", "[ActivationFunctionsTest]")
   const arma::colvec activationData1("2 3.2 4.5 100.2 1 1 2 0");
 
   // Hand-calculated values.
-  const arma::colvec desiredActivations("4.39445 14.6953 34.5211 \
-                                         46355.9 0.693147 0.693147 \
-                                         4.39445 0");
+  const arma::colvec desiredActivations("4.39445 14.6953 34.5211 "
+                                        "46355.9 0.693147 0.693147 "
+                                        "4.39445 0");
 
-  const arma::colvec desiredDerivatives("5.7277825 11.622636 19.024551 \
-                                        1024.4765 1.8862944 1.8862944 \
-                                        5.7277825 0.0");
+  const arma::colvec desiredDerivatives("5.7277825 11.622636 19.024551 "
+                                        "1024.4765 1.8862944 1.8862944 "
+                                        "5.7277825 0.0");
 
   CheckActivationCorrect<SplineFunction>(activationData1, desiredActivations);
-  CheckDerivativeCorrect<SplineFunction>(activationData1,
-                                         desiredDerivatives);
+  CheckDerivativeCorrect<SplineFunction>(activationData1, desiredDerivatives);
 }
 
 /**
@@ -689,17 +674,16 @@ TEST_CASE("SplineFunctionTest", "[ActivationFunctionsTest]")
 TEST_CASE("MultiquadFunctionTest", "[ActivationFunctionsTest]")
 {
   // Hand-calculated values.
-  const arma::colvec desiredActivations("2.23607 3.35261 4.60977 \
-                                         100.205 1.41421 1.41421 \
-                                         2.23607 1");
+  const arma::colvec desiredActivations("2.23607 3.35261 4.60977 "
+                                        "100.205 1.41421 1.41421 "
+                                        "2.23607 1");
 
-  const arma::colvec desiredDerivatives("-0.89442719 0.95447998 0.97618706 \
-                                        -0.9999502 0.70710678 -0.70710678 \
-                                        0.89442719 0.0");
+  const arma::colvec desiredDerivatives("-0.89442719 0.95447998 0.97618706 "
+                                        "-0.9999502 0.70710678 -0.70710678 "
+                                        "0.89442719 0.0");
 
   CheckActivationCorrect<MultiQuadFunction>(activationData, desiredActivations);
-  CheckDerivativeCorrect<MultiQuadFunction>(activationData,
-                                            desiredDerivatives);
+  CheckDerivativeCorrect<MultiQuadFunction>(activationData, desiredDerivatives);
 }
 
 
@@ -711,17 +695,16 @@ TEST_CASE("Poisson1FunctionTest", "[ActivationFunctionsTest]")
   const arma::colvec activationData1("-2 3.2 4.5 5 1 -1 2 0");
 
   // Hand-calculated values.
-  const arma::colvec desiredActivations("-22.1672 0.0896768 0.0388815 \
-                                         0.0269518 0 -5.43656 \
-                                         0.135335 -1");
+  const arma::colvec desiredActivations("-22.1672 0.0896768 0.0388815 "
+                                        "0.0269518 0 -5.43656 "
+                                        "0.135335 -1");
 
-  const arma::colvec desiredDerivatives("29.556224 -0.048914645 -0.027772491 \
-                                        -0.020213841 0.36787944 8.1548455 0.0 \
-                                        2.0");
+  const arma::colvec desiredDerivatives("29.556224 -0.048914645 -0.027772491 "
+                                        "-0.020213841 0.36787944 8.1548455 0.0 "
+                                        "2.0");
 
   CheckActivationCorrect<Poisson1Function>(activationData1, desiredActivations);
-  CheckDerivativeCorrect<Poisson1Function>(activationData1,
-                                           desiredDerivatives);
+  CheckDerivativeCorrect<Poisson1Function>(activationData1, desiredDerivatives);
 }
 
 /**
@@ -729,19 +712,17 @@ TEST_CASE("Poisson1FunctionTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("GaussianFunctionTest", "[ActivationFunctionsTest]")
 {
-  const arma::colvec desiredActivations("0.018315639 0.000035713 \
-                                         1.6052280551856116e-09 \
-                                         0 0.367879441 0.367879441 \
-                                         0.018315639 1");
+  const arma::colvec desiredActivations("0.018315639 0.000035713 "
+                                        "1.6052280551856116e-09 "
+                                        "0 0.367879441 0.367879441 "
+                                        "0.018315639 1");
 
-  const arma::colvec desiredDerivatives("0.073262556 -0.00022856224 \
-                                        -1.4447052e-08 0.0 -0.73575888 \
-                                        0.73575888 -0.073262556 0.0");
+  const arma::colvec desiredDerivatives("0.073262556 -0.00022856224 "
+                                        "-1.4447052e-08 0.0 -0.73575888 "
+                                        "0.73575888 -0.073262556 0.0");
 
-  CheckActivationCorrect<GaussianFunction>(activationData,
-                                           desiredActivations);
-  CheckDerivativeCorrect<GaussianFunction>(activationData,
-                                           desiredDerivatives);
+  CheckActivationCorrect<GaussianFunction>(activationData, desiredActivations);
+  CheckDerivativeCorrect<GaussianFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -753,16 +734,15 @@ TEST_CASE("HardSwishFunctionTest", "[ActivationFunctionsTest]")
   const arma::colvec activationData("3.6544 -1.9714 -5.2277 1.5448 2.1164");
 
   // Hand-calculated values.
-  const arma::colvec desiredActivations("3.6544 -0.3379636 0.0 \
-                                         1.1701345 1.8047248");
+  const arma::colvec desiredActivations("3.6544 -0.3379636 0.0 "
+                                        "1.1701345 1.8047248");
 
   // Hand-calculated values.
-  const arma::colvec desiredDerivatives("1.0 -0.15713333 0.0 1.0149333 \
-                                        1.2054667");
+  const arma::colvec desiredDerivatives("1.0 -0.15713333 0.0 1.0149333 "
+                                        "1.2054667");
 
   CheckActivationCorrect<HardSwishFunction>(activationData, desiredActivations);
-  CheckDerivativeCorrect<HardSwishFunction>
-      (activationData, desiredDerivatives);
+  CheckDerivativeCorrect<HardSwishFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -773,16 +753,15 @@ TEST_CASE("TanhExpFunctionTest", "[ActivationFunctionsTest]")
   const arma::colvec activationData("-2 3.2 4.5 1 -1 2 0");
 
   // Hand-calculated values.
-  const arma::colvec desiredActivations("-0.26903 3.20000 4.50000 \
-                                         0.991329 -0.352135 2.0 0.0000");
+  const arma::colvec desiredActivations("-0.26903 3.20000 4.50000 "
+                                        "0.991329 -0.352135 2.0 0.0000");
 
   // Hand-calculated values.
-  const arma::colvec desiredDerivatives("-0.13125793 1.0 1.0 1.0382654 \
-                                        0.029872881 1.0000218 0.76159416");
+  const arma::colvec desiredDerivatives("-0.13125793 1.0 1.0 1.0382654 "
+                                        "0.029872881 1.0000218 0.76159416");
 
   CheckActivationCorrect<TanhExpFunction>(activationData, desiredActivations);
-  CheckDerivativeCorrect<TanhExpFunction>(activationData,
-      desiredDerivatives);
+  CheckDerivativeCorrect<TanhExpFunction>(activationData, desiredDerivatives);
 }
 
 /**
@@ -795,14 +774,14 @@ TEST_CASE("SILUFunctionTest", "[ActivationFunctionsTest]")
 
   // Calculated with PyTorch.
   arma::colvec desiredActivation(
-      "-0.23840583860874176 1.7615940570831299 4.450558662414551 \
-       -0.01900840364396572 -0.2689414322376251 0.7310585975646973 \
-       0.0 9.99954605102539");
+      "-0.23840583860874176 1.7615940570831299 4.450558662414551 "
+      "-0.01900840364396572 -0.2689414322376251 0.7310585975646973 "
+      "0.0 9.99954605102539");
 
   // Calculated with PyTorch.
   arma::colvec desiredDerivate(
-      "-0.090784249 1.0907842 1.0379111 -0.015610205 0.072329488 \
-      0.92767051 0.5 1.0004086");
+      "-0.090784249 1.0907842 1.0379111 -0.015610205 0.072329488 "
+      "0.92767051 0.5 1.0004086");
 
   CheckActivationCorrect<SILUFunction>(activationData, desiredActivation);
   CheckDerivativeCorrect<SILUFunction>(activationData, desiredDerivate);
@@ -813,22 +792,22 @@ TEST_CASE("SILUFunctionTest", "[ActivationFunctionsTest]")
  */
 TEST_CASE("SwishFunctionTest", "[ActivationFunctionsTest]")
 {
-    // Random generated values.
-    const arma::colvec activationData("-2 2 4.5 -5.7 -1 1 0 10");
+  // Random generated values.
+  const arma::colvec activationData("-2 2 4.5 -5.7 -1 1 0 10");
 
-    // Calculated with PyTorch.
-    arma::colvec desiredActivation(
-            "-0.23840583860874176 1.7615940570831299 4.450558662414551 \
-       -0.01900840364396572 -0.2689414322376251 0.7310585975646973 \
-       0.0 9.99954605102539");
+  // Calculated with PyTorch.
+  arma::colvec desiredActivation(
+      "-0.23840583860874176 1.7615940570831299 4.450558662414551 "
+      "-0.01900840364396572 -0.2689414322376251 0.7310585975646973 "
+      "0.0 9.99954605102539");
 
-    // Calculated with PyTorch.
-    arma::colvec desiredDerivate(
-            "-0.090784249 1.0907842 1.0379111 -0.015610205 0.072329488 \
-      0.92767051 0.5 1.0004086");
+  // Calculated with PyTorch.
+  arma::colvec desiredDerivative(
+      "-0.090784249 1.0907842 1.0379111 -0.015610205 0.072329488 "
+      "0.92767051 0.5 1.0004086");
 
-    CheckActivationCorrect<SwishFunction>(activationData, desiredActivation);
-    CheckDerivativeCorrect<SwishFunction>(activationData, desiredDerivate);
+  CheckActivationCorrect<SwishFunction>(activationData, desiredActivation);
+  CheckDerivativeCorrect<SwishFunction>(activationData, desiredDerivative);
 }
 
 /**
@@ -838,22 +817,23 @@ TEST_CASE("HyperSinhFunctionTest", "[ActivationFunctionsTest]")
 {
   arma::colvec activationData("-1.0 0 1.2 1.5 1.8 1.0 -1.1 -1.6 -1.8");
 
-  //Hand calculated values
-	arma::colvec desiredActivation(
-		"-0.25 0.0 0.5031537851373908 0.7097598183649391 0.9807247626985599 \
-		0.3917337312146005 -0.3327500000000001 -1.0240000000000002 \
-		-1.4580000000000002");
+  // Hand calculated values
+  arma::colvec desiredActivation(
+      "-0.25 0.0 0.5031537851373908 0.7097598183649391 0.9807247626985599 "
+      "0.3917337312146005 -0.3327500000000001 -1.0240000000000002 "
+      "-1.4580000000000002");
+
+  // Hand-calculated values.
+  arma::colvec desiredDerivative(
+      "0.75 0.0 0.6035518557747915 0.7841365384144158 1.0358243921057555 "
+      "0.5143602116050813 0.9075000000000002 1.9200000000000004 2.43");
 
-	// Hand-calculated values.
-	arma::colvec desiredDerivate(
-		"0.75 0.0 0.6035518557747915 0.7841365384144158 1.0358243921057555 \
-		0.5143602116050813 0.9075000000000002 1.9200000000000004 2.43");
-  
   CheckActivationCorrect<HyperSinhFunction>(activationData, desiredActivation);
-  CheckDerivativeCorrect<HyperSinhFunction>(activationData, desiredDerivate);
+  CheckDerivativeCorrect<HyperSinhFunction>(activationData, desiredDerivative);
 
   arma::mat inputTemp(activationData.n_elem, 1);
-  double maxRelativeError = ActivationJacobianTest<HyperSinhFunction>(inputTemp);
+  double maxRelativeError = ActivationJacobianTest<HyperSinhFunction>(
+      inputTemp);
   REQUIRE(maxRelativeError <= 1e-3);
 }
 
@@ -866,20 +846,21 @@ TEST_CASE("BipolaSigmoidFunctionTest", "[ActivationFunctionsTest]")
 
   // Hand-calculated values.
   arma::colvec desiredActivation(
-      "-0.4621171572 0.0 0.5370495669 0.7818063576 0.8853516482 \
-      0.462117157 -0.50052021119 -0.7615941559 -0.9137854901");
+      "-0.4621171572 0.0 0.5370495669 0.7818063576 0.8853516482 "
+      "0.462117157 -0.50052021119 -0.7615941559 -0.9137854901");
 
   // Hand-calculated values.
-  arma::colvec desiredDerivate(
-      "0.3932238665 0.5 0.3557888813 0.1943894096 0.1080762295 \
-      0.3932238666 0.3747397590 0.2099871708 0.0824980390");
+  arma::colvec desiredDerivative(
+      "0.3932238665 0.5 0.3557888813 0.1943894096 0.1080762295 "
+      "0.3932238666 0.3747397590 0.2099871708 0.0824980390");
 
-  CheckActivationCorrect<BipolarSigmoidFunction>(activationData
-                                                ,desiredActivation);
-  CheckDerivativeCorrect<BipolarSigmoidFunction>(activationData
-                                                ,desiredDerivate);
+  CheckActivationCorrect<BipolarSigmoidFunction>(activationData,
+                                                 desiredActivation);
+  CheckDerivativeCorrect<BipolarSigmoidFunction>(activationData,
+                                                 desiredDerivative);
 
   arma::mat inputTemp(activationData.n_elem, 1);
-  double maxRelativeError = ActivationJacobianTest<BipolarSigmoidFunction>(inputTemp,-2,2);
+  double maxRelativeError = ActivationJacobianTest<BipolarSigmoidFunction>(
+      inputTemp, -2, 2);
   REQUIRE(maxRelativeError <= 1e-3);
-}
\ No newline at end of file
+}
