@@ -30,16 +30,16 @@ TEST_CASE("SimpleSoftminLayerTest", "[ANNLayerTest]")
 
   // Test the forward function.
   input = {{0.0, 0.1, 0.2},
-  	   {1.0, 1.1, 1.2},
-  	   {2.0, 2.1, 2.2},
-  	   {2.9, 2.8, 2.5}};
+           {1.0, 1.1, 1.2},
+           {2.0, 2.1, 2.2},
+           {2.9, 2.8, 2.5}};
   arma::mat actualOutput = {{0.641750, 0.636772, 0.623646},
                             {0.236086, 0.234255, 0.229426},
                             {0.086851, 0.086177, 0.084401},
-  			    {0.035311, 0.042794, 0.062526}};
+                            {0.035311, 0.042794, 0.062526}};
 
   module.Forward(input, output);
-  REQUIRE(arma::accu(arma::abs(actualOutput - output)) ==
+  REQUIRE(accu(arma::abs(actualOutput - output)) ==
              Approx(0.0).margin(1e-4));
 
   // Test the backward function.
@@ -51,7 +51,5 @@ TEST_CASE("SimpleSoftminLayerTest", "[ANNLayerTest]")
                                   {-0.0205, 0, 0},
                                   {-0.0083, 0, 0}};
 
-  REQUIRE(arma::accu(arma::abs(calculatedGradient - g)) ==
-      Approx(0.0).margin(1e-04));
-
+  REQUIRE(accu(arma::abs(calculatedGradient - g)) == Approx(0.0).margin(1e-04));
 }
