@@ -49,8 +49,8 @@ void VerifyCorrectness(const MatType& beta,
 TEMPLATE_TEST_CASE("LocalCoordinateCodingTestCodingStep",
     "[LocalCoordinateCodingTest]", arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
-  typedef arma::Col<typename MatType::elem_type> VecType;
+  using MatType = TestType;
+  using VecType = arma::Col<typename MatType::elem_type>;
 
   double lambda1 = 0.1;
   uword nAtoms = 10;
@@ -90,7 +90,7 @@ TEMPLATE_TEST_CASE("LocalCoordinateCodingTestCodingStep",
 TEMPLATE_TEST_CASE("LocalCoordinateCodingTestDictionaryStep",
     "[LocalCoordinateCodingTest]", arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
+  using MatType = TestType;
 
   const double tol = 0.1;
 
@@ -130,7 +130,7 @@ TEMPLATE_TEST_CASE("LocalCoordinateCodingTestDictionaryStep",
 TEMPLATE_TEST_CASE("LocalCoordinateCodingSerializationTest",
     "[LocalCoordinateCodingTest]", arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
+  using MatType = TestType;
 
   MatType X = randu<MatType>(100, 100);
   size_t nAtoms = 10;
@@ -183,7 +183,7 @@ TEMPLATE_TEST_CASE("LocalCoordinateCodingSerializationTest",
 TEMPLATE_TEST_CASE("LocalCoordinateCodingTrainReturnObjective",
     "[LocalCoordinateCodingTest]", arma::mat, arma::fmat)
 {
-  typedef TestType MatType;
+  using MatType = TestType;
 
   double lambda1 = 0.1;
   uword nAtoms = 10;
