@@ -8,10 +8,7 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef MLPACK_ENABLE_ANN_SERIALIZATION
-  #define MLPACK_ENABLE_ANN_SERIALIZATION
-#endif
-#include <mlpack.hpp>
+#include <mlpack/core.hpp>
 
 // #define CATCH_CONFIG_MAIN  // catch.hpp will define main()
 #define CATCH_CONFIG_RUNNER  // we will define main()
