@@ -2,7 +2,7 @@
  * @file tests/main_tests/hoeffding_tree_test.cpp
  * @author Haritha Nair
  *
- * Test mlpackMain() of hoeffding_tree_main.cpp.
+ * Test RUN_BINDING() of hoeffding_tree_main.cpp.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
@@ -12,11 +12,9 @@
 #define BINDING_TYPE BINDING_TYPE_TEST
 
 #include <mlpack/core.hpp>
-static const std::string testName = "HoeffdingTree";
-
-#include <mlpack/core/util/mlpack_main.hpp>
 #include <mlpack/methods/hoeffding_trees/hoeffding_tree_main.cpp>
-#include "test_helper.hpp"
+#include <mlpack/core/util/mlpack_main.hpp>
+#include "main_test_fixture.hpp"
 
 #include "../catch.hpp"
 #include "../test_catch_tools.hpp"
@@ -24,22 +22,7 @@ static const std::string testName = "HoeffdingTree";
 using namespace mlpack;
 using namespace data;
 
-struct HoeffdingTreeTestFixture
-{
- public:
-  HoeffdingTreeTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~HoeffdingTreeTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(HoeffdingTreeTestFixture);
 
 /**
  * Check that number of output points and
@@ -70,15 +53,15 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingTreeOutputDimensionTest",
   // Input test data.
   SetInputParam("test", std::make_tuple(info, testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_cols == testSize);
 
   // Check number of output rows equals 1 for probabilities and predictions.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_rows == 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_rows == 1);
 }
 
 /**
@@ -111,15 +94,15 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture,
   // Input test data.
   SetInputParam("test", std::make_tuple(info, testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_cols == testSize);
 
   // Check number of output rows equals 1 for probabilities and predictions.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_rows == 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_rows == 1);
 }
 
 /**
@@ -155,27 +138,25 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingTreeLabelLessTest",
   // Input test data.
   SetInputParam("test", std::make_tuple(info, testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_cols == testSize);
 
   // Check number of output rows equals number of classes in case of
   // probabilities and 1 for predictions.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_rows == 1);
-
-  // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_rows == 1);
 
   arma::Row<size_t> predictions;
   arma::mat probabilities;
-  predictions = std::move(IO::GetParam<arma::Row<size_t>>("predictions"));
-  probabilities = std::move(IO::GetParam<arma::mat>("probabilities"));
+  predictions = std::move(params.Get<arma::Row<size_t>>("predictions"));
+  probabilities = std::move(params.Get<arma::mat>("probabilities"));
 
-  bindings::tests::CleanMemory();
+  // Reset passed parameters.
+  ResetSettings();
+  CleanMemory();
 
   inputData.shed_row(inputData.n_rows - 1);
 
@@ -185,21 +166,21 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingTreeLabelLessTest",
   // Pass Labels.
   SetInputParam("labels", std::move(labels));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_cols == testSize);
 
   // Check number of output rows equals 1 for probabilities and predictions.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_rows == 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_rows == 1);
 
   // Check that initial and current predictions are same.
   CheckMatrices(
-      predictions, IO::GetParam<arma::Row<size_t>>("predictions"));
+      predictions, params.Get<arma::Row<size_t>>("predictions"));
   CheckMatrices(
-      probabilities, IO::GetParam<arma::mat>("probabilities"));
+      probabilities, params.Get<arma::mat>("probabilities"));
 }
 
 /**
@@ -230,41 +211,42 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingModelReuseTest",
   // Input test data.
   SetInputParam("test", std::make_tuple(info, testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> predictions;
   arma::mat probabilities;
-  predictions = std::move(IO::GetParam<arma::Row<size_t>>("predictions"));
-  probabilities = std::move(IO::GetParam<arma::mat>("probabilities"));
+  predictions = std::move(params.Get<arma::Row<size_t>>("predictions"));
+  probabilities = std::move(params.Get<arma::mat>("probabilities"));
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  HoeffdingTreeModel* m = params.Get<HoeffdingTreeModel*>("output_model");
+  ResetSettings();
 
   if (!data::Load("vc2_test.csv", testData, info))
     FAIL("Cannot load test dataset vc2.csv!");
 
   // Input trained model.
   SetInputParam("test", std::make_tuple(info, testData));
-  SetInputParam("input_model",
-      IO::GetParam<HoeffdingTreeModel*>("output_model"));
+  SetInputParam("input_model", m);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_cols == testSize);
 
   // Check number of output rows equals 1 for probabilities and predictions.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_rows == 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_rows == 1);
 
   // Check that initial predictions and predictions using saved model are same.
   CheckMatrices(
-      predictions, IO::GetParam<arma::Row<size_t>>("predictions"));
+      predictions, params.Get<arma::Row<size_t>>("predictions"));
   CheckMatrices(
-      probabilities, IO::GetParam<arma::mat>("probabilities"));
+      probabilities, params.Get<arma::mat>("probabilities"));
+
+  ResetSettings();
+  delete m;
 }
 
 /**
@@ -295,41 +277,42 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingModelCategoricalReuseTest",
   // Input test data.
   SetInputParam("test", std::make_tuple(info, testData));
 
-  mlpackMain();
-
-  // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  RUN_BINDING();
 
   arma::Row<size_t> predictions;
   arma::mat probabilities;
-  predictions = std::move(IO::GetParam<arma::Row<size_t>>("predictions"));
-  probabilities = std::move(IO::GetParam<arma::mat>("probabilities"));
+  predictions = std::move(params.Get<arma::Row<size_t>>("predictions"));
+  probabilities = std::move(params.Get<arma::mat>("probabilities"));
+
+  // Reset passed parameters.
+  HoeffdingTreeModel* m = params.Get<HoeffdingTreeModel*>("output_model");
+  ResetSettings();
 
   if (!data::Load("braziltourism_test.arff", testData, info))
     FAIL("Cannot load test dataset braziltourism_test.arff!");
 
   // Input trained model.
   SetInputParam("test", std::make_tuple(info, testData));
-  SetInputParam("input_model",
-      IO::GetParam<HoeffdingTreeModel*>("output_model"));
+  SetInputParam("input_model", m);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_cols == testSize);
 
   // Check number of output rows equals 1 for probabilities and predictions.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
-  REQUIRE(IO::GetParam<arma::mat>("probabilities").n_rows == 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::mat>("probabilities").n_rows == 1);
 
   // Check that initial predictions and predictions using saved model are same.
   CheckMatrices(
-      predictions, IO::GetParam<arma::Row<size_t>>("predictions"));
+      predictions, params.Get<arma::Row<size_t>>("predictions"));
   CheckMatrices(
-      probabilities, IO::GetParam<arma::mat>("probabilities"));
+      probabilities, params.Get<arma::mat>("probabilities"));
+
+  ResetSettings();
+  delete m;
 }
 
 /**
@@ -362,18 +345,13 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingMinSamplesTest",
   SetInputParam("min_samples", 10);
   SetInputParam("confidence", 0.25);
 
-  mlpackMain();
+  RUN_BINDING();
+
+  nodes = (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes();
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
-  IO::GetSingleton().Parameters()["min_samples"].wasPassed = false;
-  IO::GetSingleton().Parameters()["confidence"].wasPassed = false;
-
-  nodes = (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes();
-
-  bindings::tests::CleanMemory();
+  ResetSettings();
+  CleanMemory();
 
   if (!data::Load("vc2.csv", inputData, info))
     FAIL("Cannot load train dataset vc2.csv!");
@@ -394,11 +372,11 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingMinSamplesTest",
   SetInputParam("min_samples", 2000);
   SetInputParam("confidence", 0.25);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that small min_samples creates larger model.
-  REQUIRE((IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes() <
-      nodes);
+  REQUIRE((params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes() <
+      (size_t) nodes);
 }
 
 /**
@@ -431,18 +409,13 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingMaxSamplesTest",
   SetInputParam("max_samples", 50000);
   SetInputParam("confidence", 0.95);
 
-  mlpackMain();
+  RUN_BINDING();
+
+  nodes = (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes();
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
-  IO::GetSingleton().Parameters()["max_samples"].wasPassed = false;
-  IO::GetSingleton().Parameters()["confidence"].wasPassed = false;
-
-  nodes = (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes();
-
-  bindings::tests::CleanMemory();
+  ResetSettings();
+  CleanMemory();
 
   if (!data::Load("vc2.csv", inputData, info))
     FAIL("Cannot load train dataset vc2.csv!");
@@ -463,11 +436,11 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingMaxSamplesTest",
   SetInputParam("max_samples", 5);
   SetInputParam("confidence", 0.95);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that large max_samples creates smaller model.
-  REQUIRE(nodes <
-      (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes());
+  REQUIRE((size_t) nodes <
+      (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes());
 }
 
 /**
@@ -499,18 +472,14 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingConfidenceTest",
 
   SetInputParam("confidence", 0.95);
 
-  mlpackMain();
-
-  // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
-  IO::GetSingleton().Parameters()["confidence"].wasPassed = false;
+  RUN_BINDING();
 
   // Model with high confidence.
-  nodes = (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes();
+  nodes = (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes();
 
-  bindings::tests::CleanMemory();
+  // Reset passed parameters.
+  ResetSettings();
+  CleanMemory();
 
   if (!data::Load("vc2.csv", inputData, info))
     FAIL("Cannot load train dataset vc2.csv!");
@@ -531,10 +500,10 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingConfidenceTest",
   // Model with low confidence.
   SetInputParam("confidence", 0.25);
 
-  mlpackMain();
+  RUN_BINDING();
   // Check that higher confidence creates smaller tree.
-  REQUIRE(nodes <
-      (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes());
+  REQUIRE((size_t) nodes <
+      (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes());
 }
 
 /**
@@ -566,18 +535,14 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingPassesTest",
 
   SetInputParam("passes", 1);
 
-  mlpackMain();
-
-  // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
-  IO::GetSingleton().Parameters()["passes"].wasPassed = false;
+  RUN_BINDING();
 
   // Model with smaller number of passes.
-  nodes = (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes();
+  nodes = (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes();
 
-  bindings::tests::CleanMemory();
+  // Reset passed parameters.
+  ResetSettings();
+  CleanMemory();
 
   if (!data::Load("vc2.csv", inputData, info))
     FAIL("Cannot load train dataset vc2.csv!");
@@ -598,11 +563,11 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingPassesTest",
   // Model with larger number of passes.
   SetInputParam("passes", 100);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that model with larger number of passes has greater number of nodes.
-  REQUIRE(nodes <
-      (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes());
+  REQUIRE((size_t) nodes <
+      (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes());
 }
 
 /**
@@ -637,11 +602,11 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture,
 
   SetInputParam("confidence", 0.25);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of children is 2.
   REQUIRE(
-      (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes() - 1 == 2);
+      (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes() - 1 == 2);
 }
 
 /**
@@ -676,20 +641,14 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture,
   SetInputParam("max_samples", 50);
   SetInputParam("bins", 20);
 
-  mlpackMain();
-
-  // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
-  IO::GetSingleton().Parameters()["max_samples"].wasPassed = false;
-  IO::GetSingleton().Parameters()["numeric_split_strategy"].wasPassed = false;
-  IO::GetSingleton().Parameters()["bins"].wasPassed = false;
+  RUN_BINDING();
 
   // Initial model.
-  nodes = (IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes();
+  nodes = (params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes();
 
-  bindings::tests::CleanMemory();
+  // Reset passed parameters.
+  ResetSettings();
+  CleanMemory();
 
   if (!data::Load("vc2.csv", inputData, info))
     FAIL("Cannot load train dataset vc2.csv!");
@@ -711,11 +670,11 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture,
   SetInputParam("max_samples", 50);
   SetInputParam("bins", 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that both models have different number of nodes.
-  CHECK((IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes() !=
-      nodes);
+  CHECK((params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes() !=
+      (size_t) nodes);
 }
 
 /**
@@ -757,9 +716,9 @@ TEST_CASE_METHOD(HoeffdingTreeTestFixture, "HoeffdingBinningTest",
   SetInputParam("observations_before_binning", 100);
   SetInputParam("confidence", 0.25);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that no splitting has happened.
-  REQUIRE((IO::GetParam<HoeffdingTreeModel*>("output_model"))->NumNodes()
+  REQUIRE((params.Get<HoeffdingTreeModel*>("output_model"))->NumNodes()
       == 1);
 }
