@@ -3,44 +3,26 @@
  * @author Atharva Khandait
  * @author Heet Sankesara
  *
- * Test mlpackMain() of kfn_main.cpp.
+ * Test RUN_BINDING() of kfn_main.cpp.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <string>
-
 #define BINDING_TYPE BINDING_TYPE_TEST
-static const std::string testName = "K-FurthestNeighborsSearch";
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/util/mlpack_main.hpp>
-#include "test_helper.hpp"
 #include <mlpack/methods/neighbor_search/kfn_main.cpp>
+#include <mlpack/core/util/mlpack_main.hpp>
+#include "main_test_fixture.hpp"
 
 #include "../test_catch_tools.hpp"
 #include "../catch.hpp"
 
 using namespace mlpack;
 
-struct KFNTestFixture
-{
- public:
-  KFNTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~KFNTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(KFNTestFixture);
 
 /*
  * Check that we can't provide reference and query matrices
@@ -63,9 +45,7 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNEqualDimensionTest",
   SetInputParam("query", std::move(queryData));
   SetInputParam("k", (int) 10);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -82,28 +62,19 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNInvalidKTest",
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 101);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  delete IO::GetParam<KFNModel*>("output_model");
-  IO::GetParam<KFNModel*>("output_model") = NULL;
+  delete params.Get<KFNModel*>("output_model");
+  params.Get<KFNModel*>("output_model") = NULL;
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["k"].wasPassed = false;
+  ResetSettings();
 
-  // SetInputParam("reference", referenceData);
-  // SetInputParam("k", (int) 0); // Invalid.
-
-  // REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-
-  // IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  // IO::GetSingleton().Parameters()["k"].wasPassed = false;
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) -1); // Invalid.
 
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -124,9 +95,7 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNInvalidKQueryDataTest",
   SetInputParam("query", std::move(queryData));
   SetInputParam("k", (int) 101);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -142,9 +111,7 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNLeafSizeTest",
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("leaf_size", (int) -1); // Invalid.
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -160,15 +127,13 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNRefModelTest",
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Input pre-trained model.
   SetInputParam("input_model",
-      std::move(IO::GetParam<KFNModel*>("output_model")));
+      std::move(params.Get<KFNModel*>("output_model")));
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -185,9 +150,7 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNInvalidTreeTypeTest",
   SetInputParam("k", (int) 10);
   SetInputParam("tree_type", (string) "min-rp"); // Invalid.
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -204,9 +167,7 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNInvalidAlgoTest",
   SetInputParam("k", (int) 10);
   SetInputParam("algorithm", (string) "triple_tree"); // Invalid.
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -223,25 +184,21 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNInvalidEpsilonTest",
   SetInputParam("k", (int) 10);
   SetInputParam("epsilon", (double) -1); // Invalid.
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["epsilon"].wasPassed = false;
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("epsilon", (double) 2); // Invalid.
 
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["epsilon"].wasPassed = false;
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("epsilon", (double) 1); // Invalid.
 
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -258,25 +215,21 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNInvalidPercentageTest",
   SetInputParam("k", (int) 10);
   SetInputParam("percentage", (double) -1); // Invalid.
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["percentage"].wasPassed = false;
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("percentage", (double) 0); // Invalid.
 
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["epsilon"].wasPassed = false;
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("percentage", (double) 2); // Invalid.
 
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -293,15 +246,15 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNOutputDimensionTest",
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check the neighbors matrix has 4 points for each input point.
-  REQUIRE(IO::GetParam<arma::Mat<size_t>>("neighbors").n_rows == 10);
-  REQUIRE(IO::GetParam<arma::Mat<size_t>>("neighbors").n_cols == 100);
+  REQUIRE(params.Get<arma::Mat<size_t>>("neighbors").n_rows == 10);
+  REQUIRE(params.Get<arma::Mat<size_t>>("neighbors").n_cols == 100);
 
   // Check the distances matrix has 4 points for each input point.
-  REQUIRE(IO::GetParam<arma::mat>("distances").n_rows == 10);
-  REQUIRE(IO::GetParam<arma::mat>("distances").n_cols == 100);
+  REQUIRE(params.Get<arma::mat>("distances").n_rows == 10);
+  REQUIRE(params.Get<arma::mat>("distances").n_cols == 100);
 }
 
 /**
@@ -321,30 +274,30 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNModelReuseTest",
   SetInputParam("query", queryData);
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> neighbors;
   arma::mat distances;
-  neighbors = std::move(IO::GetParam<arma::Mat<size_t>>("neighbors"));
-  distances = std::move(IO::GetParam<arma::mat>("distances"));
-
-  // bindings::tests::CleanMemory();
+  neighbors = std::move(params.Get<arma::Mat<size_t>>("neighbors"));
+  distances = std::move(params.Get<arma::mat>("distances"));
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["query"].wasPassed = false;
+  KFNModel* m = params.Get<KFNModel*>("output_model");
+  params.Get<KFNModel*>("output_model") = NULL;
+  CleanMemory();
+  ResetSettings();
 
   // Input saved model, pass the same query and keep k unchanged.
-  SetInputParam("input_model",
-      std::move(IO::GetParam<KFNModel*>("output_model")));
+  SetInputParam("input_model", m);
   SetInputParam("query", queryData);
+  SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that initial output matrices and the output matrices using
   // saved model are equal.
-  CheckMatrices(neighbors, IO::GetParam<arma::Mat<size_t>>("neighbors"));
-  CheckMatrices(distances, IO::GetParam<arma::mat>("distances"));
+  CheckMatrices(neighbors, params.Get<arma::Mat<size_t>>("neighbors"));
+  CheckMatrices(distances, params.Get<arma::mat>("distances"));
 }
 
 /*
@@ -362,27 +315,25 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNDifferentEpsilonTest",
   SetInputParam("k", (int) 10);
   SetInputParam("epsilon", (double) 0.2);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> neighbors;
   arma::mat distances;
-  neighbors = std::move(IO::GetParam<arma::Mat<size_t>>("neighbors"));
-  distances = std::move(IO::GetParam<arma::mat>("distances"));
+  neighbors = std::move(params.Get<arma::Mat<size_t>>("neighbors"));
+  distances = std::move(params.Get<arma::mat>("distances"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["epsilon"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("epsilon", (double) 0.8);
 
-  mlpackMain();
+  RUN_BINDING();
 
   CheckMatricesNotEqual(neighbors,
-      IO::GetParam<arma::Mat<size_t>>("neighbors"));
+      params.Get<arma::Mat<size_t>>("neighbors"));
   CheckMatricesNotEqual(distances,
-      IO::GetParam<arma::mat>("distances"));
+      params.Get<arma::mat>("distances"));
 }
 
 /*
@@ -400,27 +351,25 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNDifferentPercentageTest",
   SetInputParam("k", (int) 10);
   SetInputParam("percentage", (double) 0.2);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> neighbors;
   arma::mat distances;
-  neighbors = std::move(IO::GetParam<arma::Mat<size_t>>("neighbors"));
-  distances = std::move(IO::GetParam<arma::mat>("distances"));
+  neighbors = std::move(params.Get<arma::Mat<size_t>>("neighbors"));
+  distances = std::move(params.Get<arma::mat>("distances"));
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["percentage"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("percentage", (double) 0.8);
 
-  mlpackMain();
+  RUN_BINDING();
 
   CheckMatricesNotEqual(neighbors,
-      IO::GetParam<arma::Mat<size_t>>("neighbors"));
+      params.Get<arma::Mat<size_t>>("neighbors"));
   CheckMatricesNotEqual(distances,
-      IO::GetParam<arma::mat>("distances"));
+      params.Get<arma::mat>("distances"));
 }
 
 /*
@@ -436,28 +385,27 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNRandomBasisTest",
   // Random input, some k <= number of reference points.
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
-  IO::SetPassed("random_basis");
+  SetInputParam("random_basis", true);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> neighbors;
   arma::mat distances;
-  neighbors = std::move(IO::GetParam<arma::Mat<size_t>>("neighbors"));
-  distances = std::move(IO::GetParam<arma::mat>("distances"));
-  REQUIRE(IO::GetParam<KFNModel*>("output_model")->RandomBasis() == true);
+  neighbors = std::move(params.Get<arma::Mat<size_t>>("neighbors"));
+  distances = std::move(params.Get<arma::mat>("distances"));
+  REQUIRE(params.Get<KFNModel*>("output_model")->RandomBasis() == true);
 
-  bindings::tests::CleanMemory();
-
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["random_basis"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
+  SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  CheckMatrices(neighbors, IO::GetParam<arma::Mat<size_t>>("neighbors"));
-  CheckMatrices(distances, IO::GetParam<arma::mat>("distances"));
-  REQUIRE(IO::GetParam<KFNModel*>("output_model")->RandomBasis() == false);
+  CheckMatrices(neighbors, params.Get<arma::Mat<size_t>>("neighbors"));
+  CheckMatrices(distances, params.Get<arma::mat>("distances"));
+  REQUIRE(params.Get<KFNModel*>("output_model")->RandomBasis() == false);
 }
 
 /*
@@ -474,22 +422,23 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNTrueNeighborDistanceTest",
   SetInputParam("reference", referenceData);
   SetInputParam("k", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Mat<size_t> neighbors;
   arma::mat distances;
-  neighbors = std::move(IO::GetParam<arma::Mat<size_t>>("neighbors"));
-  distances = std::move(IO::GetParam<arma::mat>("distances"));
+  neighbors = std::move(params.Get<arma::Mat<size_t>>("neighbors"));
+  distances = std::move(params.Get<arma::mat>("distances"));
 
-  delete IO::GetParam<KFNModel*>("output_model");
-  IO::GetParam<KFNModel*>("output_model") = NULL;
+  delete params.Get<KFNModel*>("output_model");
+  params.Get<KFNModel*>("output_model") = NULL;
 
   SetInputParam("reference", referenceData);
   SetInputParam("true_neighbors", neighbors);
   SetInputParam("true_distances", distances);
   SetInputParam("epsilon", (double) 0.5);
+  SetInputParam("k", (int) 10);
 
-  REQUIRE_NOTHROW(mlpackMain());
+  REQUIRE_NOTHROW(RUN_BINDING());
 
   // True output matrices have incorrect shape.
   arma::Mat<size_t> dummyNeighbors;
@@ -497,20 +446,17 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNTrueNeighborDistanceTest",
   dummyNeighbors.randu(20, 100);
   dummyDistances.randu(20, 100);
 
-  delete IO::GetParam<KFNModel*>("output_model");
-  IO::GetParam<KFNModel*>("output_model") = NULL;
+  delete params.Get<KFNModel*>("output_model");
+  params.Get<KFNModel*>("output_model") = NULL;
 
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-  IO::GetSingleton().Parameters()["true_neighbors"].wasPassed = false;
-  IO::GetSingleton().Parameters()["true_distances"].wasPassed = false;
+  ResetSettings();
 
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("true_neighbors", std::move(dummyNeighbors));
   SetInputParam("true_distances", std::move(dummyDistances));
+  SetInputParam("k", (int) 10);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /*
@@ -529,9 +475,6 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNAllAlgorithmsTest",
   arma::mat queryData;
   queryData.randu(3, 90); // 90 points in 3 dimensions.
 
-  // Keep some k <= number of reference points same over all.
-  SetInputParam("k", (int) 10);
-
   arma::Mat<size_t> neighborsCompare;
   arma::mat distancesCompare;
 
@@ -545,31 +488,30 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNAllAlgorithmsTest",
     SetInputParam("reference", referenceData);
     SetInputParam("query", queryData);
     SetInputParam("algorithm", algorithms[i]);
+    SetInputParam("k", (int) 10);
 
-    mlpackMain();
+    RUN_BINDING();
 
     if (i == 0)
     {
       neighborsCompare = std::move
-          (IO::GetParam<arma::Mat<size_t>>("neighbors"));
-      distancesCompare = std::move(IO::GetParam<arma::mat>("distances"));
+          (params.Get<arma::Mat<size_t>>("neighbors"));
+      distancesCompare = std::move(params.Get<arma::mat>("distances"));
     }
     else
     {
-      neighbors = std::move(IO::GetParam<arma::Mat<size_t>>("neighbors"));
-      distances = std::move(IO::GetParam<arma::mat>("distances"));
+      neighbors = std::move(params.Get<arma::Mat<size_t>>("neighbors"));
+      distances = std::move(params.Get<arma::mat>("distances"));
 
       CheckMatrices(neighborsCompare, neighbors);
       CheckMatrices(distancesCompare, distances);
     }
 
-    delete IO::GetParam<KFNModel*>("output_model");
-    IO::GetParam<KFNModel*>("output_model") = NULL;
+    delete params.Get<KFNModel*>("output_model");
+    params.Get<KFNModel*>("output_model") = NULL;
 
     // Reset passed parameters.
-    IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-    IO::GetSingleton().Parameters()["query"].wasPassed = false;
-    IO::GetSingleton().Parameters()["algorithm"].wasPassed = false;
+    ResetSettings();
   }
 }
 
@@ -590,9 +532,6 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNAllTreeTypesTest",
   arma::mat queryData;
   queryData.randu(3, 90); // 90 points in 3 dimensions.
 
-  // Keep some k <= number of reference points same over all.
-  SetInputParam("k", (int) 10);
-
   arma::Mat<size_t> neighborsCompare;
   arma::mat distancesCompare;
 
@@ -606,31 +545,30 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNAllTreeTypesTest",
     SetInputParam("reference", referenceData);
     SetInputParam("query", queryData);
     SetInputParam("tree_type", treetypes[i]);
+    SetInputParam("k", (int) 10);
 
-    mlpackMain();
+    RUN_BINDING();
 
     if (i == 0)
     {
       neighborsCompare = std::move(
-          IO::GetParam<arma::Mat<size_t>>("neighbors"));
-      distancesCompare = std::move(IO::GetParam<arma::mat>("distances"));
+          params.Get<arma::Mat<size_t>>("neighbors"));
+      distancesCompare = std::move(params.Get<arma::mat>("distances"));
     }
     else
     {
-      neighbors = std::move(IO::GetParam<arma::Mat<size_t>>("neighbors"));
-      distances = std::move(IO::GetParam<arma::mat>("distances"));
+      neighbors = std::move(params.Get<arma::Mat<size_t>>("neighbors"));
+      distances = std::move(params.Get<arma::mat>("distances"));
 
       CheckMatrices(neighborsCompare, neighbors);
       CheckMatrices(distancesCompare, distances);
     }
 
-    delete IO::GetParam<KFNModel*>("output_model");
-    IO::GetParam<KFNModel*>("output_model") = NULL;
+    delete params.Get<KFNModel*>("output_model");
+    params.Get<KFNModel*>("output_model") = NULL;
 
     // Reset passed parameters.
-    IO::GetSingleton().Parameters()["reference"].wasPassed = false;
-    IO::GetSingleton().Parameters()["query"].wasPassed = false;
-    IO::GetSingleton().Parameters()["tree_type"].wasPassed = false;
+    ResetSettings();
   }
 }
 
@@ -648,23 +586,22 @@ TEST_CASE_METHOD(KFNTestFixture, "KFNDifferentLeafSizes",
   SetInputParam("k", (int) 10);
   SetInputParam("leaf_size", (int) 1);
 
-  mlpackMain();
+  RUN_BINDING();
 
-  REQUIRE(IO::GetParam<KFNModel*>("output_model")->LeafSize() == (int) 1);
-
-  bindings::tests::CleanMemory();
+  REQUIRE(params.Get<KFNModel*>("output_model")->LeafSize() == (int) 1);
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Input saved model, pass the same query and keep k unchanged.
   SetInputParam("reference", std::move(referenceData));
   SetInputParam("k", (int) 10);
   SetInputParam("leaf_size", (int) 10);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that initial output matrices and the output matrices using
   // saved model are equal.
-  REQUIRE(IO::GetParam<KFNModel*>("output_model")->LeafSize() == (int) 10);
+  REQUIRE(params.Get<KFNModel*>("output_model")->LeafSize() == (int) 10);
 }
