@@ -12,7 +12,7 @@
 #define BINDING_TYPE BINDING_TYPE_TEST
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/metrics/lmetric.hpp>
+#include <mlpack/core/distances/lmetric.hpp>
 #include <mlpack/methods/lmnn/lmnn_main.cpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 
@@ -542,7 +542,7 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffRegularizationTest",
 }
 
 /**
- * Ensure that different value of range results in a
+ * Ensure that different value of update interval results in a
  * different output matrix.
  */
 TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffRangeTest",
@@ -573,7 +573,7 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffRangeTest",
   SetInputParam("input", std::move(inputData));
   SetInputParam("labels", std::move(labels));
   SetInputParam("linear_scan",  (bool) true);
-  SetInputParam("range", 100);
+  SetInputParam("update_interval", 100);
 
   RUN_BINDING();
 
@@ -674,9 +674,9 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNDiffPassesTest",
 }
 
 /**
- * Ensure that number of targets, range, batch size must be always positive
- * and regularization, step size, max iterations, rank, passes & tolerance are
- * always non-negative 
+ * Ensure that number of targets, update interval, batch size must be always
+ * positive and regularization, step size, max iterations, rank, passes &
+ * tolerance are always non-negative.
  */
 TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
                 "[LMNNMainTest][BindingTests]")
@@ -701,12 +701,12 @@ TEST_CASE_METHOD(LMNNTestFixture, "LMNNBoundsTest",
   // Reset settings.
   ResetSettings();
 
-  // Test for range value.
+  // Test for update interval value.
 
   // Input training data.
   SetInputParam("input", inputData);
   SetInputParam("labels", labels);
-  SetInputParam("range", (int) 0);
+  SetInputParam("update_interval", (int) 0);
 
   REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 
