@@ -234,7 +234,7 @@ TEST_CASE_METHOD(SparseCodingTestFixture, "SparseCodingModelVerTest",
   LoadData(inputData, testData);
 
   mat initialDictionary = inputData.cols(0, 1);
-  SparseCoding* c = new SparseCoding();
+  SparseCoding<>* c = new SparseCoding<>();
 
   // Input trained model and initial_dictionary.
   SetInputParam("input_model", c);
@@ -340,8 +340,8 @@ TEST_CASE_METHOD(SparseCodingTestFixture, "SparseCodingModelReuseTest",
   arma::mat codes = std::move(params.Get<arma::mat>("codes"));
 
   // Reset passed parameters.
-  SparseCoding* m = params.Get<SparseCoding*>("output_model");
-  params.Get<SparseCoding*>("output_model") = NULL;
+  SparseCoding<>* m = params.Get<SparseCoding<>*>("output_model");
+  params.Get<SparseCoding<>*>("output_model") = NULL;
   CleanMemory();
   ResetSettings();
 
@@ -420,11 +420,10 @@ TEST_CASE_METHOD(SparseCodingTestFixture, "SparseCodingDiffMaxItrTest",
 
   // Check that initial outputs and final outputs
   // using two models model are different.
-  REQUIRE(arma::accu(dictionary ==
+  REQUIRE(accu(dictionary ==
       params.Get<arma::mat>("dictionary")) < dictionary.n_elem);
 
-  REQUIRE(arma::accu(codes ==
-      params.Get<arma::mat>("codes")) < codes.n_elem);
+  REQUIRE(accu(codes == params.Get<arma::mat>("codes")) < codes.n_elem);
 }
 
 /**
@@ -469,10 +468,9 @@ TEST_CASE_METHOD(SparseCodingTestFixture, "SparseCodingDiffObjToleranceTest",
 
   // Check that initial outputs and final outputs
   // using two models model are different.
-  REQUIRE(arma::accu(dictionary ==
+  REQUIRE(accu(dictionary ==
       params.Get<arma::mat>("dictionary")) < dictionary.n_elem);
-  REQUIRE(arma::accu(codes ==
-      params.Get<arma::mat>("codes")) < codes.n_elem);
+  REQUIRE(accu(codes == params.Get<arma::mat>("codes")) < codes.n_elem);
 }
 
 /**
@@ -518,11 +516,10 @@ TEST_CASE_METHOD(SparseCodingTestFixture,
 
   // Check that initial outputs and final outputs
   // using two models model are different.
-  REQUIRE(arma::accu(dictionary ==
+  REQUIRE(accu(dictionary ==
       params.Get<arma::mat>("dictionary")) < dictionary.n_elem);
 
-  REQUIRE(arma::accu(codes ==
-      params.Get<arma::mat>("codes")) < codes.n_elem);
+  REQUIRE(accu(codes == params.Get<arma::mat>("codes")) < codes.n_elem);
 }
 
 /**
@@ -567,11 +564,10 @@ TEST_CASE_METHOD(SparseCodingTestFixture, "SparseCodingDiffL1Test",
 
   // Check that initial outputs and final outputs
   // using two models model are different.
-  REQUIRE(arma::accu(dictionary ==
+  REQUIRE(accu(dictionary ==
       params.Get<arma::mat>("dictionary")) < dictionary.n_elem);
 
-  REQUIRE(arma::accu(codes ==
-      params.Get<arma::mat>("codes")) < codes.n_elem);
+  REQUIRE(accu(codes == params.Get<arma::mat>("codes")) < codes.n_elem);
 }
 
 /**
@@ -616,11 +612,10 @@ TEST_CASE_METHOD(SparseCodingTestFixture, "SparseCodingDiffL2Test",
 
   // Check that initial outputs and final outputs
   // using two models model are different.
-  REQUIRE(arma::accu(dictionary ==
+  REQUIRE(accu(dictionary ==
       params.Get<arma::mat>("dictionary")) < dictionary.n_elem);
 
-  REQUIRE(arma::accu(codes ==
-      params.Get<arma::mat>("codes")) < codes.n_elem);
+  REQUIRE(accu(codes == params.Get<arma::mat>("codes")) < codes.n_elem);
 }
 
 /**
@@ -667,9 +662,8 @@ TEST_CASE_METHOD(SparseCodingTestFixture, "SparseCodingDiffL1L2Test",
 
   // Check that initial outputs and final outputs
   // using two models model are different.
-  REQUIRE(arma::accu(dictionary ==
+  REQUIRE(accu(dictionary ==
       params.Get<arma::mat>("dictionary")) < dictionary.n_elem);
 
-  REQUIRE(arma::accu(codes ==
-      params.Get<arma::mat>("codes")) < codes.n_elem);
+  REQUIRE(accu(codes == params.Get<arma::mat>("codes")) < codes.n_elem);
 }
