@@ -37,8 +37,8 @@ TEST_CASE("BootstrapNoWeightsTest", "[RandomForestTest]")
     arma::Row<size_t> bootstrapLabels;
     arma::rowvec bootstrapWeights;
 
-    Bootstrap<false>(dataset, labels, weights, bootstrapDataset,
-        bootstrapLabels, bootstrapWeights);
+    DefaultBootstrap().Bootstrap<false>(dataset, labels, weights,
+        bootstrapDataset, bootstrapLabels, bootstrapWeights);
 
     REQUIRE(bootstrapDataset.n_cols == 1000);
     REQUIRE(bootstrapDataset.n_rows == 1);
@@ -72,8 +72,8 @@ TEST_CASE("BootstrapWeightsTest", "[RandomForestTest]")
     arma::Row<size_t> bootstrapLabels;
     arma::rowvec bootstrapWeights;
 
-    Bootstrap<true>(dataset, labels, weights, bootstrapDataset,
-        bootstrapLabels, bootstrapWeights);
+    DefaultBootstrap().Bootstrap<true>(dataset, labels, weights,
+        bootstrapDataset, bootstrapLabels, bootstrapWeights);
 
     REQUIRE(bootstrapDataset.n_cols == 1000);
     REQUIRE(bootstrapDataset.n_rows == 1);
@@ -124,7 +124,7 @@ TEST_CASE("UnweightedNumericLearningTest", "[RandomForestTest]")
     FAIL("Cannot load dataset vc2.csv");
   arma::Row<size_t> labels;
   if (!data::Load("vc2_labels.txt", labels))
-    FAIL("Cannot load dataset vc2.csv");
+    FAIL("Cannot load dataset vc2_labels.txt");
 
   // Build a random forest and a decision tree.
   RandomForest<> rf(dataset, labels, 3, 20 /* 20 trees */, 1, 1e-7);
@@ -314,7 +314,7 @@ TEST_CASE("LeafSizeDatasetTest", "[RandomForestTest]")
     FAIL("Cannot load dataset vc2.csv");
   arma::Row<size_t> labels;
   if (!data::Load("vc2_labels.txt", labels))
-    FAIL("Cannot load dataset vc2.csv");
+    FAIL("Cannot load dataset vc2_labels.txt");
 
   // Build a random forest with a leaf size equal to the number of points in the
   // dataset.
@@ -350,7 +350,7 @@ TEST_CASE("RandomForestSerializationTest", "[RandomForestTest]")
     FAIL("Cannot load dataset vc2.csv");
   arma::Row<size_t> labels;
   if (!data::Load("vc2_labels.txt", labels))
-    FAIL("Cannot load dataset vc2.csv");
+    FAIL("Cannot load dataset vc2_labels.txt");
 
   RandomForest<> rf(dataset, labels, 3, 10 /* 10 trees */, 1);
 
@@ -607,3 +607,191 @@ TEST_CASE("ExtraTreesAccuracyTest", "[RandomForestTest]")
 
   REQUIRE(accuracy >= 0.85);
 }
+
+/**
+ * Test ComputeAverageUniqueness.
+ * 
+ * Average uniqueness is defined as average over the lifetime of an event
+ * of how many other events are active at every point in time.
+ */
+TEST_CASE("ComputeAverageUniquenessTest", "[RandomForestTest]")
+{
+  arma::umat indM(2 /* rows */, 3 /* cols */, arma::fill::zeros);
+
+  // indM = [1 1 1 0 0 0
+  //         0 0 1 1 0 0
+  //         0 0 0 0 1 1]
+  // The last event is fully isolated.
+  // The first two events overlap in the third column.
+  indM(0, 0) = 0;
+  indM(1, 0) = 2;
+  indM(0, 1) = 2;
+  indM(1, 1) = 3;
+  indM(0, 2) = 4;
+  indM(1, 2) = 5;
+
+  arma::vec concurrency(6);
+  concurrency[0] = 1;
+  concurrency[1] = 1;
+  concurrency[2] = 2;
+  concurrency[3] = 1;
+  concurrency[4] = 1;
+  concurrency[5] = 1;
+
+  const arma::vec invConcurrency(1.0 / concurrency);
+  arma::vec       avg(3);
+
+  avg[0] = SequentialBootstrap<>::ComputeAverageUniqueness(
+      indM(0, 0), indM(1, 0), invConcurrency);
+  avg[1] = SequentialBootstrap<>::ComputeAverageUniqueness(
+      indM(0, 1), indM(1, 1), invConcurrency);
+  avg[2] = SequentialBootstrap<>::ComputeAverageUniqueness(
+      indM(0, 2), indM(1, 2), invConcurrency);
+
+  REQUIRE(avg(0) == Approx(5.0 / 6.0));
+  REQUIRE(avg(1) == Approx(0.75));
+  REQUIRE(avg(2) == Approx(1.0));
+}
+
+/**
+ * Test ComputeNextDrawProbabilities.
+ */
+TEST_CASE("ComputeNextDrawProbabilitiesTest", "[RandomForestTest]")
+{
+  arma::uvec phi1(2);
+  arma::umat indM(2 /* rows */, 3 /* cols */, arma::fill::zeros);
+
+  phi1[0] = 1u;
+
+  indM(0, 0) = 0;
+  indM(1, 0) = 2;
+  indM(0, 1) = 2;
+  indM(1, 1) = 3;
+  indM(0, 2) = 4;
+  indM(1, 2) = 5;
+
+  arma::vec concurrency(6, arma::fill::zeros);
+  concurrency[2] = 1;
+  concurrency[3] = 1;
+
+  arma::vec invConcurrency(concurrency.n_rows, arma::fill::ones);
+  arma::vec delta2(3);
+
+  // Compute the probabilities that observations 0, 1, 2 are drawn after
+  // observation 1 has already been drawn.
+  SequentialBootstrap<>::ComputeNextDrawProbabilities(
+      phi1, 1, concurrency, invConcurrency, indM, delta2);
+
+  REQUIRE(delta2(0) == Approx(5.0 / 14.0));
+  // Should have the lowest probability as it has already been drawn.
+  REQUIRE(delta2(1) == Approx(3.0 / 14.0));
+  // Should have the highest probability as this event does not overlap
+  // with others.
+  REQUIRE(delta2(2) == Approx(6.0 / 14.0));
+}
+
+/**
+ * Test ComputeSamples.
+ */
+TEST_CASE("ComputeSamplesTest", "[RandomForestTest]")
+{
+  arma::umat indM(2 /* rows */, 6 /* cols */, arma::fill::zeros);
+
+  indM(0, 0) = 0;
+  indM(1, 0) = 2;
+  indM(0, 1) = 2;
+  indM(1, 1) = 3;
+  indM(0, 2) = 4;
+  indM(1, 2) = 5;
+
+  indM(1, 3) = indM(1, 4) = indM(1, 5) = 5;
+
+  SequentialBootstrap bootstrap(indM);
+  const arma::uvec phi(bootstrap.ComputeSamples(6));
+
+  // Can only check that the next draw does not yield indices
+  // outside of the range of observations.
+  REQUIRE(phi(0) < 6);
+  REQUIRE(phi(1) < 6);
+  REQUIRE(phi(2) < 6);
+}
+
+/**
+ * Test SequentialBootstrap.
+ */
+TEST_CASE("SequentialBootstrapTest", "[RandomForestTest]")
+{
+  const arma::mat ds(10 /* rows */, 6 /* cols */, arma::fill::randu);
+  const arma::Row<size_t> labels{ 1, 0, 0, 0, 0, 0 };
+  const arma::rowvec weights(6, arma::fill::ones);
+  arma::umat indM(2 /* rows */, 6 /* cols */, arma::fill::zeros);
+
+  indM(0, 0) = 0;
+  indM(1, 0) = 2;
+  indM(0, 1) = 2;
+  indM(1, 1) = 3;
+  indM(0, 2) = 4;
+  indM(1, 2) = 5;
+
+  indM(1, 3) = indM(1, 4) = indM(1, 5) = 5;
+
+  SequentialBootstrap<> bootstrap(indM);
+  arma::mat bsDataset;
+  arma::Row<size_t> bsLabels;
+  arma::rowvec bsWeights;
+
+  bootstrap.Bootstrap<true>(
+      ds, labels, weights, bsDataset, bsLabels, bsWeights);
+
+  // Check that dimensions are the same.
+  REQUIRE(ds.n_rows == bsDataset.n_rows);
+  REQUIRE(ds.n_cols == bsDataset.n_cols);
+  REQUIRE(labels.n_cols == bsLabels.n_cols);
+  REQUIRE(weights.n_cols == bsWeights.n_cols);
+}
+
+TEST_CASE("RandomForestWithSequentialBootstrapTest", "[RandomForestTest]")
+{
+  const arma::mat ds(10 /* rows */, 6 /* cols */, arma::fill::randu);
+  const arma::Row<size_t> labels{ 1, 0, 0, 0, 0, 0 };
+  const arma::rowvec weights(6, arma::fill::ones);
+  arma::umat indM(2 /* rows */, 6 /* cols */, arma::fill::zeros);
+
+  indM(0, 0) = 0;
+  indM(1, 0) = 2;
+  indM(0, 1) = 2;
+  indM(1, 1) = 3;
+  indM(0, 2) = 4;
+  indM(1, 2) = 5;
+
+  indM(1, 3) = indM(1, 4) = indM(1, 5) = 5;
+
+  SequentialBootstrap<> bootstrap(indM);
+
+  using RF = RandomForest<
+      mlpack::GiniGain,
+      mlpack::MultipleRandomDimensionSelect,
+      mlpack::BestBinaryNumericSplit,
+      mlpack::AllCategoricalSplit,
+      true,
+      mlpack::SequentialBootstrap<>>;
+
+  RF rf(
+      ds,
+      labels,
+      2,
+      weights,
+      20,
+      1,
+      1e-7,
+      0,
+      mlpack::MultipleRandomDimensionSelect(),
+      bootstrap);
+
+  // Sanity check: ensure that the predictions are reasonable.
+  arma::Row<size_t> predictions;
+  rf.Classify(ds, predictions);
+
+  for (size_t i = 0; i < predictions.n_elem; ++i)
+    REQUIRE((predictions[i] == 0 || predictions[i] == 1));
+}
